{$APPTYPE CONSOLE}
Type
  Integer=LongInt;

Const
  TaskID='pinball';
  InFile=TaskID+'.in';
  OutFile=TaskID+'.out';
  MaxSize=1002;
  Infinity=MaxLongInt Div 3;

Const
  InputDirMap:Array[1..4]Of Integer=(0,2,3,1);
  DirReverse:Array[0..3]Of Integer=(3,2,1,0); {xor 3}
  DirDRow:Array[0..3]Of Integer=(-1,0,0,1);
  DirDCol:Array[0..3]Of Integer=(0,-1,1,0);

Type
  TDirMap=Array[0..MaxSize+1,0..MaxSize+1,0..3]Of Integer;

Var
  ARow,ACol,ADir,BRow,BCol,BDir:Integer;
  Rows,Cols:Integer;
  MirrorNum:Integer;
  Mirror:Array[0..MaxSize+1,0..MaxSize+1]Of Integer;
  DirA,DirB:TDirMap;
  Res:Integer;
  ResRow,ResCol,ResMirror:Integer;

Procedure Load;
Var
  I,CRow,CCol:Integer;
Begin
  FillChar(Mirror,SizeOf(Mirror),0);
  Assign(Input,InFile);
  ReSet(Input);
  Read(Rows,Cols,MirrorNum);
  Dec(MirrorNum);
  Read(ARow,ACol,ADir);
  ADir:=DirReverse[InputDirMap[ADir]];
  Read(BRow,BCol,BDir);
  BDir:=InputDirMap[BDir];
  For I:=1 To MirrorNum Do Begin
    Read(CRow,CCol);
    Read(Mirror[CRow,CCol]);
  End;
  Dec(ARow,DirDRow[ADir]);
  Dec(ACol,DirDCol[ADir]);
  Inc(BRow,DirDRow[BDir]);
  Inc(BCol,DirDCol[BDir]);
  Close(Input);
End;

Procedure TraceRoute(SRow,SCol,SDir:Integer; Var Map:TDirMap);
Var
  Len:Integer;
  CRow,CCol,CDir:Integer;
Begin
  Len:=0;
  CRow:=SRow;
  CCol:=SCol;
  CDir:=SDir;
  Repeat
    Inc(Len);
    Inc(CRow,DirDRow[CDir]);
    Inc(CCol,DirDCol[CDir]);
    CDir:=CDir Xor Mirror[CRow,CCol];
    Map[CRow,CCol,CDir]:=Len;
  Until (CRow<1) Or (CRow>Rows) Or (CCol<1) Or (CCol>Cols) Or ((CRow=SRow) And (CCol=SCol) And (CDir=SDir));
End;

Procedure FindPathCycles;
Var
  Row,Col,CRes,D1,D2:Integer;
Begin
  For Row:=1 To Rows Do
    For Col:=1 To Cols Do
      If Mirror[Row,Col]=0 Then
        For D1:=0 To 3 Do If DirA[Row,Col,D1]>0 Then Begin
          For D2:=D1+1 To 3 Do If DirA[Row,Col,D2]>0 Then Begin
            CRes:=DirA[BRow,BCol,BDir]-1-Abs(DirA[Row,Col,D1]-DirA[Row,Col,D2]);
            If CRes<Res Then Begin
              Res:=CRes;
              ResRow:=Row;
              ResCol:=Col;
              ResMirror:=D1 Xor D2;
            End;
            Break;
          End;
          Break;
        End;
End;

Procedure FindBoringCells;
Var
  CRes,Row,Col,D1:Integer;
  Ok:Boolean;
Begin
  For Row:=1 To Rows Do
    For Col:=1 To Cols Do
      If Mirror[Row,Col]=0 Then Begin
        Ok:=True;
        For D1:=0 To 3 Do If DirA[Row,Col,D1]>0 Then Begin
          Ok:=False;
          Break;
        End;
        If Ok Then Begin
          CRes:=DirA[BRow,BCol,BDir]-1;
          If CRes<Res Then Begin
            Res:=CRes;
            ResRow:=Row;
            ResCol:=Col;
            ResMirror:=1;
          End;
          Exit;
        End;
      End;
End;

Procedure FindOtherCycles;
Var
  CRes,Row,Col,D1,D2:Integer;
  Ok:Boolean;
Begin
  FillChar(DirB,SizeOf(DirB),0);
  For Row:=1 To Rows Do
    For Col:=1 To Cols Do
      If Mirror[Row,Col]=0 Then
        For D1:=0 To 3 Do If DirA[Row,Col,D1]>0 Then Begin
          Ok:=True;
          For D2:=D1+1 To 3 Do If DirA[Row,Col,D2]>0 Then Begin
            Ok:=False;
            Break;
          End;
          If Ok And (DirB[Row,Col,D1 Xor 1]=0) And (DirB[Row,Col,D1 Xor 2]=0) Then Begin
            TraceRoute(Row,Col,D1 Xor 1,DirB);
            If DirB[Row,Col,D1 Xor 1]>0 Then Begin
              CRes:=DirA[BRow,BCol,BDir]-1+DirB[Row,Col,D1 Xor 1];
              If CRes<Res Then Begin
                Res:=CRes;
                ResRow:=Row;
                ResCol:=Col;
                ResMirror:=1;
              End;
            End;
          End;
          Break;
        End;
End;

Procedure FindCrossings;
Var
  Row,Col,CRes,D1,D2:Integer;
Begin
  For Row:=1 To Rows Do
    For Col:=1 To Cols Do
      If Mirror[Row,Col]=0 Then
        For D1:=0 To 3 Do If DirA[Row,Col,D1]>0 Then Begin
          For D2:=0 To 3 Do If DirB[Row,Col,D2]>0 Then Begin
            CRes:=DirA[Row,Col,D1]+DirB[Row,Col,D2]-1;
            If CRes<Res Then Begin
              Res:=CRes;
              ResRow:=Row;
              ResCol:=Col;
              ResMirror:=D1 Xor DirReverse[D2];
            End;
            Break;
          End;
          Break;
        End;
End;

Procedure Solve;
Begin
  FillChar(DirA,SizeOf(DirA),0);
  TraceRoute(ARow,ACol,ADir,DirA);
  Res:=Infinity;
  If DirA[BRow,BCol,BDir]>0 Then Begin
    FindPathCycles;
    If Res>=Infinity Then Begin
      FindBoringCells;
      If Res>=Infinity Then
        FindOtherCycles;
    End;
  End Else Begin
    FillChar(DirB,SizeOf(DirB),0);
    TraceRoute(BRow,BCol,DirReverse[BDir],DirB);
    FindCrossings;
  End;
End;

Procedure Save;
Begin
  Assign(Output,OutFile);
  ReWrite(Output);
  If Res<Infinity Then
    WriteLn(ResRow,' ',ResCol,' ',ResMirror)
  Else
    WriteLn('NO SOLUTION');
  Close(Output);
End;

Begin
  Load;
  Solve;
  Save;
End.
