
{$R-,O-,Q-}
{$apptype CONSOLE}
{$define CHECK_GATES}
{.$define PRINT_TRACE}

const
    inFile = 'skier.in';
    outFile = 'skier.out';

    maxN = 500;
    maxM = maxN * 2 + 3;
    inf = 1e20;
    maxC = 10000;

type
    float = extended;

    TGate = record
        x : array[1..2] of integer;
        y : integer;
        cost : integer;
        left, right : integer;
    end;

    TKind = (_gate, _start, _finish);

    TPoint = record
        kind : TKind;
        x, y : integer;
        best : float;
        from : integer;
    end;

var
    n : integer;
    g : array[1..maxN + 2] of TGate;
    x0, y0, x1, y1 : integer;

    m : integer;
    p : array[1..maxM] of TPoint;

    rsq : array[1..maxM] of integer;
    plist, invplist : array[1..maxM] of integer;

procedure SortGates;

    function IsLess(const a, b : TGate) : boolean;
    begin
        if a.y <> b.y then
            IsLess := a.y < b.y
        else
            IsLess := a.x[1] < b.x[1];
    end;
    
    procedure QSort(lo, hi : integer);
    var
        i, j : integer;
        mid : TGate;
        tmp : TGate;

    begin
        if lo >= hi then
            exit;

        mid := g[(lo + hi) div 2];
        i := lo;
        j := hi;
        
        while i <= j do begin
            while IsLess(g[i], mid) do
                inc(i);
            while IsLess(mid, g[j]) do
                dec(j);
            if i <= j then begin
                tmp := g[i];
                g[i] := g[j];
                g[j] := tmp;
                inc(i);
                dec(j);
            end;
        end;

        QSort(lo, j);
        QSort(i, hi);
    end;

begin
    QSort(1, n);
end;

procedure CheckGates;
var
    i, j, k : integer;
    
begin
    i := 1;
    while i <= n do begin
        j := i;
        while (j < n) and (g[i].y = g[j+1].y) do
            inc(j);

        for k := i + 1 to j do
            if g[k].x[1] <= g[k-1].x[2] then
                runerror(239);
                
        i := j + 1;           
    end;
end;

procedure MakePoints;
var
    i : integer;

    function Insert(x, y : integer; kind : TKind) : integer;
    begin
        inc(m);
        p[m].x := x;
        p[m].y := y;
        p[m].kind := kind;
        p[m].from := 0;
        result := m;
    end;

begin
    m := 0;
    Insert(x1, y1, _finish);
    for i := 1 to n do begin
        g[i].left := Insert(g[i].x[1], g[i].y, _gate);
        g[i].right := Insert(g[i].x[2], g[i].y, _gate);
    end;    
    Insert(x0, y0, _start);
end;

procedure Eval(origin : integer);
var
    pbase, gbase : integer;
    i, j : integer;
    cur : float;

    function IsLess(const a, b : TPoint) : boolean;
    begin
        result := (a.x - p[origin].x) * (b.y - p[origin].y) - (b.x - p[origin].x) * (a.y - p[origin].y) > 0;
    end;

    function IsEqual(const a, b : TPoint) : boolean;
    begin
        result := (a.x - p[origin].x) * (b.y - p[origin].y) - (b.x - p[origin].x) * (a.y - p[origin].y) = 0;
    end;

    function h(n : integer) : integer;
    begin
        result := (n xor (n - 1) + 1) div 2; 
    end;

    procedure RSQInit;
    begin
        fillchar(rsq, sizeof(integer) * (m + 1), 0);
    end;

    function RSQGet(i : integer) : integer;
    begin
        result := 0;
        while i > 0 do begin
            inc(result, rsq[i]);
            dec(i, h(i));
        end;
    end;

    procedure RSQUpdate(i : integer; delta : integer);
    begin
        while i <= m do begin
            inc(rsq[i], delta);
            inc(i, h(i));
        end;
    end;

    procedure QSort(lo, hi : integer);
    var
        mid : TPoint;
        tmp : integer;
        i, j : integer;

    begin
        if lo >= hi then
            exit;

        mid := p[plist[(lo + hi) div 2]];
        i := lo;
        j := hi;

        while i <= j do begin
            while IsLess(p[plist[i]], mid) do
                inc(i);
            while IsLess(mid, p[plist[j]]) do
                dec(j);
            if i <= j then begin
                tmp := plist[i];
                plist[i] := plist[j];
                plist[j] := tmp;
                inc(i);
                dec(j);
            end;
        end;

        QSort(lo, j);
        QSort(i, hi);
    end;

    procedure MakePolar;
    var
        i, j : integer;

    begin
        for i := 1 to pbase do
            plist[i] := i;
        QSort(1, pbase);
        j := 0;
        for i := 1 to pbase do begin
            if (i = 1) or not IsEqual(p[plist[i]], p[plist[i-1]]) then
                inc(j);
            invplist[plist[i]] := j;
        end;
    end;

    function Dist(const a, b : TPoint) : float;
    begin
        Dist := sqrt(sqr(a.x - b.x) + sqr(a.y - b.y));
    end;

begin
    if p[origin].kind = _finish then begin
        cur := 0;
        for i := 1 to n do
            cur := cur + g[i].cost;
        p[origin].from := origin;
        p[origin].best := cur;
        exit;
    end;

    gbase := n;
    while (gbase >= 1) and (g[gbase].y >= p[origin].y) do
        dec(gbase);

    pbase := origin;
    while (pbase >= 1) and (p[pbase].y >= p[origin].y) do
        dec(pbase);

    MakePolar;
    RSQInit;

    j := gbase;
    for i := pbase downto 1 do begin
        while (j >= 1) and (g[j].y >= p[i].y) do begin
            RSQUpdate(invplist[g[j].left], g[j].cost);
            RSQUpdate(invplist[g[j].right] + 1, -g[j].cost);
            dec(j);
        end;

        cur := p[i].best + Dist(p[origin], p[i]) - RSQGet(invplist[i]);
        if (p[origin].from = 0) or ((p[origin].from <> 0) and (p[origin].best > cur)) then begin
            p[origin].best := cur;
            p[origin].from := i;
        end;
    end;
end;

procedure Solve;
var
    i : integer;

begin
    SortGates;
{$ifdef CHECK_GATES}
    CheckGates;
{$endif}    
    MakePoints;
    for i := 1 to m do
        Eval(i);
end;

procedure ReadData;
var
    i : integer;

begin
    assign(input, inFile);
    reset(input);

    read(n);
    if not eoln then
        runerror(239);
    readln;
    
    if (n < 0) or (n > maxN) then
        runerror(239);
        
    read(x0);
    if eoln then
        runerror(239);
    read(y0);
    if not eoln then
        runerror(239);
    readln;
    
    read(x1);
    if eoln then
        runerror(239);
    read(y1);
    if not eoln then
        runerror(239);
    readln;
    
    if (abs(x0) > maxC) or (abs(y0) > maxC) or (abs(x1) > maxC) or (abs(y1) > maxC) or (y0 <= y1) then
        runerror(239);
        
    for i := 1 to n do begin
        read(g[i].x[1]);
        if eoln then
            runerror(239);
        read(g[i].x[2]);
        if eoln then
            runerror(239);
        read(g[i].y);
        if eoln then
            runerror(239);
        read(g[i].cost);
        if not eoln then
            runerror(239);
        readln;
        
        if (g[i].cost < 0) or (g[i].cost > maxC) then
            runerror(239);

        if (abs(g[i].x[1]) > maxC) or
           (abs(g[i].x[2]) > maxC) or
           (abs(g[i].y) > maxC) or
           (g[i].x[1] >= g[i].x[2]) or
           (g[i].y <= y1) or
           (g[i].y >= y0) then
            runerror(239);
    end;
    
    if not eof then
        runerror(239);
    
    close(input);
end;


procedure WriteData;
var
    i : integer;
    
begin
    assign(output, outFile);
    rewrite(output);

    writeln(p[m].best:0:6);
{$ifdef PRINT_TRACE}
    i := m;
    repeat
        writeln(p[i].x, ' ', p[i].y);
        if p[i].from = i then
            break;
        i := p[i].from;
    until false;
{$endif}
    close(output);
end;

begin
    ReadData;
    Solve;
    WriteData;
end.

