{
          

    :     
    :      ,  
    :     
}

{$APPTYPE CONSOLE}
{$O-,Q+,R+}
{$DEFINE ALLOWMULTITEST}

program light;

uses
    math, sysutils;

const
    maxn = 100;
    maxc = 1000;
    minv = 0.01;
    maxv = 10000;
    mind = 1e-2;

    eps = 1e-8;
    infty = 1e100;

var
    n: longint;
    px, py: extended;
    x, y: array [0..maxn + 1] of extended;
    v: extended;
    u: array [0..maxn] of boolean;
    ans: array [0..maxn] of extended;

{ ,   y   x  z }
function between(x, y, z: extended): boolean;
begin
    between := 
        ((x - eps < y) and (y < z + eps)) or
        ((z - eps < y) and (y < x + eps));
end;

{      }
function dist(x0, y0, x1, y1, x2, y2: extended): extended;
var
    a1, a2, b1, b2, c1, c2: extended;
    d: extended;
    x, y: extended;
begin
    a1 := x1 - x2;
    b1 := y2 - y1;
    c1 := a1 * x1 + b1 * y1;
    a2 := b1;
    b2 := - a1;
    c2 := a2 * x0 + b2 * y0;
    d := a1 * b2 - a2 * b1;
    assert(abs(d) > eps);
    x := (c1 * b2 - c2 * b1) / d;
    y := (a1 * c2 - a2 * c1) / d;
    if between(x1, x, x2) and between(y1, y, y2) then
    begin
        dist := hypot(x - x0, y - y0);
    end else begin
        dist := min(hypot(x1 - x0, y1 - y0), hypot(x2 - x0, y2 - y0));
    end;
end;

{ ,       }
function inside(x0, y0: extended): boolean;
var
    s, t: extended;
    i: longint;
begin
    s := 0;
    for i := 1 to n do
    begin
        t := arctan2((x[i + 1] - x0) * (y[i] - y0) - (x[i] - x0) * (y[i + 1] - y0), 
            (x[i] - x0) * (x[i + 1] - x0) + (y[i] - y0) * (y[i + 1] - y0));
        s := s + t;
    end;
    inside := abs(s) > eps;
end;

{    ,       ang }
procedure project(x0, y0: extended; ang: extended; var xp, yp: extended);
var
    c: extended;
begin
    c := x0 * cos(ang) + y0 * sin(ang);
    xp := c * cos(ang);
    yp := c * sin(ang);
end;

function angle(x1, y1, x2, y2: extended): extended;
begin
    angle := arctan2(x1 * y2 - x2 * y1, x1 * x2 + y1 * y2);
end;

procedure read_and_verify;
var
    s: extended;
    i: longint;
begin
    if eoln then runerror(239);
    read(px);
    if eoln then runerror(239);
    read(py);
    if eoln then runerror(239);
    read(v);
    if not eoln then runerror(239);
    readln;

    if (px < eps) or (px > maxc) or (py < eps) or (py > maxc) then
        runerror(239);
    if (v < minv) or (v > maxv) then
        runerror(239);

    if eoln then runerror(239);
    read(n);
    if not eoln then runerror(239);
    readln;

    if (n < 3) or (n > maxn) then runerror(239);

    for i := 1 to n do
    begin
        if eoln then runerror(239);
        read(x[i]);
        if eoln then runerror(239);
        read(y[i]);
        if not eoln then runerror(239);
        readln;

        if (x[i] < 0) or (x[i] > maxc) or (y[i] < 0) or (y[i] > maxc) then 
            runerror(239);
    end;

    {$IFNDEF ALLOWMULTITEST}
    if not eof then runerror(239);
    {$ENDIF}

    x[n + 1] := x[1];
    y[n + 1] := y[1];
    x[0] := x[n];
    y[0] := y[n];

    s := 0;
    for i := 1 to n do
        s := s + (x[i] - x[i + 1]) * (y[i + 1] + y[i]);
    if s < 0 then
        runerror(239);

    for i := 1 to n do
    begin
        if dist(0, 0, x[i], y[i], x[i+1], y[i+1]) < mind then
        begin
            writeln('Lamp is too close to the house ', i);
            runerror(239);
        end;
        if dist(px, py, x[i], y[i], x[i+1], y[i+1]) < mind then
        begin
            writeln('Peter is initially too close to the house ', i);
            runerror(239);
        end;

        if angle(x[i + 1] - x[i], y[i + 1] - y[i], x[i - 1] - x[i], y[i - 1] - y[i]) < eps then
        begin
            writeln('Polygon is not convex ', i);
            runerror(239);
        end;
    end;

    if inside(0, 0) then
    begin
        writeln('Lamp is inside the house');
        runerror(239);
    end;

    if inside(px, py) then
    begin
        writeln('Peters is initially inside the house');
        runerror(239);
    end;
end;

{ 
    ,   ,    , 
          ang
}
function walk(xp, yp: extended; p: longint; ang: extended): extended;
var
    d1, d2: extended;
    x0, y0: extended;
    mina, maxa: extended;
    mini, maxi: longint;
    i: longint;
    an: array [1..maxn] of extended;
begin
    if u[p] then begin
        walk := ans[p];
        exit;
    end;
    u[p] := true;
    ans[p] := infty;

    if abs(xp * sin(ang) - yp * cos(ang)) < eps then
    begin
        ans[p] := 0;
        walk := ans[p];
        exit;
    end;

    project(xp, yp, ang, x0, y0);

    mina := infty;
    maxa := -infty;
    mini := 0;
    maxi := 0;
    for i := 1 to n do
    begin   
        if hypot(x[i] - xp, y[i] - yp) > eps then
        begin
            an[i] := angle(x[i] - xp, y[i] - yp, x0 - xp, y0 - yp);
            if mina > an[i] then begin
                mina := an[i];
                mini := i;
            end;
            if maxa < an[i] then begin
                maxa := an[i];
                maxi := i;
            end;
        end;
    end;

    assert(mini <> 0);
    assert(maxi <> 0);

    if (maxa < eps) or (mina > -eps) or (maxa - mina > pi - eps) then
    begin
        ans[p] := hypot(x0 - xp, y0 - yp);
    end else begin
        d1 := hypot(x[maxi] - xp, y[maxi] - yp) + walk(x[maxi], y[maxi], maxi, ang);
        d2 := hypot(x[mini] - xp, y[mini] - yp) + walk(x[mini], y[mini], mini, ang);
        ans[p] := min(d1, d2);
    end;
    walk := ans[p];
end;

var
    mina, maxa, minpa, maxpa: extended;
    alpha: extended;
    i: longint;
    dmin, dmax, answer: extended;

begin
    assign(input, 'light.in');
    reset(input);
    assign(output, 'light.out');
    rewrite(output);

    read_and_verify;

    mina := infty;
    maxa := -infty;
    minpa := infty;
    maxpa := -infty;

    for i := 1 to n do
    begin
        alpha := arctan2(y[i], x[i]);
        if alpha < mina then mina := alpha;
        if alpha > maxa then maxa := alpha;

        alpha := angle(x[i] - px, y[i] - py, 0 - px, 0 - py);
        if alpha < minpa then minpa := alpha;
        if alpha > maxpa then maxpa := alpha;
    end;

    if (maxpa < eps) or (minpa > -eps) or (maxpa - minpa > pi - eps) then
    begin
        answer := 0;
    end else begin
        fillchar(u, sizeof(u), 0);
        dmin := walk(px, py, 0, mina);
        fillchar(u, sizeof(u), 0);
        dmax := walk(px, py, 0, maxa);
        answer := min(dmin, dmax);
    end;

    writeln(answer / v :0 :20);

    close(input);
    close(output);
end.