{$R-,Q-,S-,O+}
Program MakeLoveNotWar;
Uses SysUtils;

Type
  Integer=LongInt;

Const
  TaskID='triples';
  InFile=TaskID+'.in';
  OutFile=TaskID+'.out';
  MaxN=102;
  TimeLimit=4.8/24/60/60;
  NumTries=20;
  BulkSize=1000;

Type
  TArr=Array[1..MaxN,1..MaxN]Of Integer;
  TPerm=Array[1..MaxN]Of Integer;

Var
  N:Integer;
  AB,BC,CA:TArr;
  Cur,Best:Integer;
  BPermA,BPermB,BPermC:TPerm;
  PermA,PermB,PermC:TPerm;
  Start,Finish:TDateTime;

Procedure ReadArr(Var A:TArr);
Var
  I,J:Integer;
Begin
  For I:=1 To N Do
    For J:=1 To N Do Read(A[I,J]);
End;

Procedure Load;
Begin
  Assign(Input,InFile);
  ReSet(Input);
  Read(N);
  ReadArr(AB);
  ReadArr(BC);
  ReadArr(CA);
  Close(Input);
End;

Function Calculate:Integer;
Var
  R,I:Integer;
Begin
  R:=0;
  For I:=1 To N Do
    Inc(R,AB[PermA[I],PermB[I]]+BC[PermB[I],PermC[I]]+CA[PermC[I],PermA[I]]);
  Calculate:=R;
End;

Procedure Swap(Var A,B:Integer);
Var
  T:Integer;
Begin
  T:=A;
  A:=B;
  B:=T;
End;

Procedure MakeRandomPerm(Var P:TPerm);
Var
  I,J:Integer;
Begin
  For I:=1 To N Do P[I]:=I;
  For I:=1 To N-1 Do Begin
    J:=I+Random(N-I+1);
    If I<>J Then Swap(P[I],P[J]);
  End;
End;

Procedure RandomStart;
Begin
  MakeRandomPerm(PermA);
  MakeRandomPerm(PermB);
  MakeRandomPerm(PermC);
  Cur:=Calculate;
End;

Procedure Optimize;
Var
  BulkStep:Integer;
  Diff,I,J:Integer;
Begin
  While Now<Finish Do Begin
    For BulkStep:=1 To BulkSize Do Begin
      Repeat
        I:=Random(N)+1;
        J:=Random(N)+1;
      Until I<>J;
      Case Random(3) Of
        0:Begin
          Diff:=AB[PermA[J],PermB[I]]+CA[PermC[I],PermA[J]]+AB[PermA[I],PermB[J]]+CA[PermC[J],PermA[I]]-
                AB[PermA[I],PermB[I]]-CA[PermC[I],PermA[I]]-AB[PermA[J],PermB[J]]-CA[PermC[J],PermA[J]];
          If Diff>0 Then Begin
            Inc(Cur,Diff);
            Swap(PermA[I],PermA[J]);
          End;
        End;
        1:Begin
          Diff:=BC[PermB[J],PermC[I]]+AB[PermA[I],PermB[J]]+BC[PermB[I],PermC[J]]+AB[PermA[J],PermB[I]]-
                BC[PermB[I],PermC[I]]-AB[PermA[I],PermB[I]]-BC[PermB[J],PermC[J]]-AB[PermA[J],PermB[J]];
          If Diff>0 Then Begin
            Inc(Cur,Diff);
            Swap(PermB[I],PermB[J]);
          End;
        End;
        2:Begin
          Diff:=CA[PermC[J],PermA[I]]+BC[PermB[I],PermC[J]]+CA[PermC[I],PermA[J]]+BC[PermB[J],PermC[I]]-
                CA[PermC[I],PermA[I]]-BC[PermB[I],PermC[I]]-CA[PermC[J],PermA[J]]-BC[PermB[J],PermC[J]];
          If Diff>0 Then Begin
            Inc(Cur,Diff);
            Swap(PermC[I],PermC[J]);
          End;
        End;
      End;
    End;
  End;
End;

Procedure GreedyStart;
Var
  I,J,K,BJ,BK,Best,Curr:Integer;
  MarkB,MarkC:Array[1..MaxN]Of Boolean;
Begin
  MakeRandomPerm(PermA);
  FillChar(MarkB,SizeOf(MarkB),False);
  FillChar(MarkC,SizeOf(MarkC),False);
  For I:=1 To N Do Begin
    Best:=-1;
    For J:=1 To N Do If Not MarkB[J] Then 
      For K:=1 To N Do If Not MarkC[K] Then Begin
        Curr:=AB[PermA[I],J]+BC[J,K]+CA[K,PermA[I]];
        If Curr>Best Then Begin
          Best:=Curr;
          BJ:=J;
          BK:=K;
        End;
      End;
    PermB[I]:=BJ;
    PermC[I]:=BK;
    MarkB[BJ]:=True;
    MarkC[BK]:=True;
  End;
  Cur:=Calculate;
End;

Procedure MegaGreedyStart;
Var
  Step:Integer;
  I,J,K,BI,BJ,BK,Best,Curr:Integer;
  MarkA,MarkB,MarkC:Array[1..MaxN]Of Boolean;
Begin 
  FillChar(MarkA,SizeOf(MarkA),False);
  FillChar(MarkB,SizeOf(MarkB),False);
  FillChar(MarkC,SizeOf(MarkC),False);
  For Step:=1 To N Do Begin
    Best:=-1;
    For I:=1 To N Do If Not MarkA[I] Then
      For J:=1 To N Do If Not MarkB[J] Then
        For K:=1 To N Do If Not MarkC[K] Then Begin
          Curr:=AB[I,J]+BC[J,K]+CA[K,I];
          If Curr>Best Then Begin
            Best:=Curr;
            BI:=I;
            BJ:=J;
            BK:=K;
          End;
        End;  
    PermA[Step]:=BI;
    PermB[Step]:=BJ;
    PermC[Step]:=BK;
    MarkA[BI]:=True;
    MarkB[BJ]:=True;
    MarkC[BK]:=True;
  End;
  Cur:=Calculate;
//  WriteLn('Elapsed: ',FloatToStr((Now-Start)*24*60*60),' secs.');
End;

Procedure Solve;
Var
  I:Integer;
  Start2:TDateTime;
Begin
  Best:=-1;
  MegaGreedyStart;
(*  Start2:=Now;
  For I:=1 To NumTries Do Begin
    Finish:=Start2+I/NumTries*(TimeLimit-(Start2-Start));
    If I=1 Then
      {Do nothing}
    Else If I<=3*NumTries Div 4 Then
      GreedyStart
    Else 
      RandomStart;
    Optimize;*)
    If Cur>Best Then Begin
      Best:=Cur;
      BPermA:=PermA;
      BPermB:=PermB;
      BPermC:=PermC;
      WriteLn(Best);
    End;
{  End;}
End;

Procedure Save;
Var
  I:Integer;
Begin
  Assign(Output,OutFile);
  ReWrite(Output);
  For I:=1 To N Do
    WriteLn(BPermA[I],' ',BPermB[I],' ',BPermC[I]);
  Close(Output);
End;

Begin
  Start:=Now;
  RandSeed:=543819581;
  Randomize;
  Load;
  Solve;
  Save;
End.
