import java.io.*;
import java.util.*;

public class quest_op
{
    String[] rooms;
    Task[][] roomTasks;
    String[][] roomItems;

    int init;
    int last;
    int[] parent;

    HashMap keys;
    HashSet items;
    HashSet tasks;

    ArrayList result;

    void readData() throws IOException
    {
        BufferedReader in = new BufferedReader(new FileReader("quest.in"));

        int n = Integer.parseInt(in.readLine());
        rooms = new String[n];
        for (int i = 0; i < n; i++)
            rooms[i] = in.readLine().trim();

        keys = new HashMap();
        int m = Integer.parseInt(in.readLine());
        for (int i = 0; i < m; i++)
        {
            Key key = Key.readKey(in);
            keys.put(key.getName(), key);
        }

        roomTasks = new Task[n][];
        roomItems = new String[n][];
        for (int i = 0; i < n; i++)
        {
            StringTokenizer st = new StringTokenizer(in.readLine());
            int c = Integer.parseInt(st.nextToken());
            int o = Integer.parseInt(st.nextToken());
            int s = Integer.parseInt(st.nextToken());

            roomTasks[i] = new Task[c + o];
            for (int j = 0; j < c; j++)
                roomTasks[i][j] = Task.readTask(in, i, Task.CHARACTER);
            for (int j = c; j < c + o; j++)
                roomTasks[i][j] = Task.readTask(in, i, Task.OBJECT);

            roomItems[i] = new String[s];
            for (int j = 0; j < s; j++)
                roomItems[i][j] = in.readLine().trim();
        }

        String roomName = in.readLine().trim();
        init = 0;
        while (init < rooms.length && !roomName.equals(rooms[init]))
            init++;

        roomName = in.readLine().trim();
        last = 0;
        while (last < rooms.length && !roomName.equals(rooms[last]))
            last++;

        in.close();
    }

    void roomCleaning(int roomID)
    {
        for (int i = 0; i < roomItems[roomID].length; i++)
        {
            addItem(roomItems[roomID][i]);
            result.add("pick " + roomItems[roomID][i]);
        }
        for (int i = 0; i < roomTasks[roomID].length; i++)
            addTask(roomTasks[roomID][i]);
    }

    void moveUp(int roomID)
    {
        while (parent[roomID] != roomID)
        {
            roomID = parent[roomID];
            result.add("go to " + rooms[roomID]);
        }
    }

    void moveDown(int roomID)
    {
        if (parent[roomID] != roomID)
        {
            moveDown(parent[roomID]);
            result.add("go to " + rooms[roomID]);
        }

    }

    String decorateStringArray(String prefix, String suffix, String[] sArray)
    {
        StringBuffer sb = new StringBuffer();
        sb.append(prefix);
        for (int i = 0; i < sArray.length; i++)
        {
            sb.append(sArray[i]);
            if (i == sArray.length - 2)
                sb.append(" and ");
            else if (i != sArray.length - 1)
                sb.append(", ");
        }
        sb.append(suffix);

        return sb.toString();
    }

    void addItem(String itemName)
    {
        items.add(itemName);
        for (Iterator iterator = tasks.iterator(); iterator.hasNext();)
            ((Task) iterator.next()).itemIsFound(itemName);
    }

    void addTask(Task task)
    {
        tasks.add(task);
        for (Iterator iterator = items.iterator(); iterator.hasNext();)
            task.itemIsFound((String) iterator.next());
    }

    boolean doStep()
    {
        boolean used = false;
        for (Iterator iterator = items.iterator(); iterator.hasNext();)
        {
            String s = (String) iterator.next();
            Key key = (Key) keys.get(s);
            if (key != null)
            {
                int i = key.getRoomOne();
                int j = key.getRoomTwo();
                if (parent[j] != -1)
                {
                    int k = i;
                    i = j;
                    j = k;
                }
                if (parent[i] != -1 && parent[j] == -1)
                {
                    if (init != i)
                    {
                        moveUp(init);
                        moveDown(i);
                    }
                    result.add("open door to " + rooms[j]);
                    result.add("go to " + rooms[j]);

                    parent[j] = i;
                    init = j;

                    iterator.remove();
                    keys.remove(s);

                    used = true;
                    break;
                }
            }
        }
        if (used)
        {
            roomCleaning(init);
            return true;
        }


        for (Iterator iterator = tasks.iterator(); iterator.hasNext();)
        {
            Task task = (Task) iterator.next();
            if (task.isPerformed())
            {
                if (init != task.getRoom())
                {
                    moveUp(init);
                    moveDown(task.getRoom());
                }
                init = task.getRoom();

                String[] incoming = task.getIncoming();
                String[] outgoing = task.getOutgoing();
                if (task.type == Task.OBJECT)
                    result.add(decorateStringArray("use ", " on " + task.getName(), incoming));
                else
                {
                    result.add("talk to " + task.getName());
                    result.add(decorateStringArray("give ", " to " + task.getName(), incoming));
                }
                result.add(decorateStringArray("take ", " from " + task.getName(), outgoing));

                if (task.getType() == Task.CHARACTER)
                {
                    for (int i = 0; i < incoming.length; i++)
                        items.remove(incoming[i]);
                }
                iterator.remove();
                for (int i = 0; i < outgoing.length; i++)
                    addItem(outgoing[i]);

                return true;
            }
        }

        return false;
    }

    void solve()
    {
        parent = new int[rooms.length];
        for (int i = 0; i < parent.length; i++)
            parent[i] = -1;
        parent[init] = init;

        items = new HashSet();
        tasks = new HashSet();

        result = new ArrayList();

        roomCleaning(init);

        boolean done;
        do
            done = doStep();
        while (init != last && done);

        if (init != last)
        {
            result.clear();
            result.add("dead princess");
        }
        else
            result.add("save princess");
    }

    void printAns() throws IOException
    {
        PrintWriter out = new PrintWriter(new FileWriter("quest.out"));

        for (int i = 0; i < result.size(); i++)
            out.println((String) result.get(i));

        out.close();
    }

    public static void main(String[] args) throws IOException
    {
        quest_op problem = new quest_op();

        problem.readData();
        problem.solve();
        problem.printAns();
    }

    private static class Key
    {
        private String name;
        private int roomOne;
        private int roomTwo;

        static Key readKey(BufferedReader in) throws IOException
        {
            Key key = new Key();

            StringTokenizer st = new StringTokenizer(in.readLine());
            key.roomOne = Integer.parseInt(st.nextToken()) - 1;
            key.roomTwo = Integer.parseInt(st.nextToken()) - 1;
            key.name = st.nextToken("\t\n\r\f").trim();

            return key;
        }

        private Key()
        {
        }

        String getName()
        {
            return name;
        }

        int getRoomOne()
        {
            return roomOne;
        }

        int getRoomTwo()
        {
            return roomTwo;
        }
    }

    private static class Task
    {
        static final int OBJECT = 0;
        static final int CHARACTER = 1;

        private int type;
        private HashSet itemsToFind;

        private String name;
        private int room;
        private String[] outgoing;
        private String[] incoming;

        static Task readTask(BufferedReader in, int room, int type) throws IOException
        {
            Task task = new Task();

            task.room = room;
            task.type = type;
            task.name = in.readLine().trim();

            ArrayList list = new ArrayList();
            StringTokenizer st = new StringTokenizer(in.readLine(), ",\t\n\r\f");
            while (st.hasMoreElements())
                list.add(st.nextToken().trim());
            task.incoming = new String[list.size()];
            for (int i = 0; i < list.size(); i++)
                task.incoming[i] = (String) list.get(i);

            task.itemsToFind = new HashSet(list);

            list.clear();
            st = new StringTokenizer(in.readLine(), ",\t\n\r\f");
            while (st.hasMoreElements())
                list.add(st.nextToken().trim());
            task.outgoing = new String[list.size()];
            for (int i = 0; i < list.size(); i++)
                task.outgoing[i] = (String) list.get(i);

            return task;
        }

        private Task()
        {
        }

        int getType()
        {
            return type;
        }

        String getName()
        {
            return name;
        }

        int getRoom()
        {
            return room;
        }

        String[] getOutgoing()
        {
            return outgoing;
        }

        String[] getIncoming()
        {
            return incoming;
        }

        void itemIsFound(String item)
        {
            itemsToFind.remove(item);
        }

        boolean isPerformed()
        {
            return itemsToFind.size() == 0;
        }
    }
}
