#include <iostream>
#include <cmath>
#include <string>
#include <sstream>
#include <vector>
#include <deque>
#include <map>
#include <set>
#include <functional>
#include <algorithm>
#include <cassert>

using namespace std;

#ifdef __GNUC__
typedef long long i64; typedef unsigned long long u64;
#endif

#ifndef __GNUC__
typedef __int64 i64; typedef unsigned __int64 u64;
#endif

typedef long double real;

typedef vector<int> VI;  typedef vector<VI> VVI;
typedef vector<string> VS;  typedef vector<VS> VVS;

#define int i64

#define forn(i, n) for(int i = 0; i < (n); i++)
#define fors(i, s) forn(i, s.length())
#define forv(i, v) forn(i, v.size())

#define pb push_back
#define all(v) v.begin(), v.end()

#define INF 0x3ffffffffff
#define NMAX 5000
#define MMAX 100000

int random(int size)
{
    return rand() % size;
}

typedef int trow[NMAX];
typedef struct tlist
{
    int num;
    int inf;
    int d;
    tlist * next;
    tlist(int inf = 0, int d = 0, tlist * next = NULL) :
        inf(inf), d(d), next(next) { };
} tlist;

int n = 0, m = 0;
int ans = 0;
trow d;
tlist * graph[NMAX];
int change[MMAX];
trow used;

void listAdd(tlist * &l, int inf, int d)
{
    tlist * x = new tlist(inf, d, l);
    x->next = l;
    l = x;
}

int readint()
{
    char c = ' ';
    while (c < '0' || c > '9')
        c = getc(stdin);
    int result = 0;
    while (c >= '0' && c <= '9')
    {
        result = result * 10 + c - '0';
        c = getc(stdin);
    }
    return result;
}

void rec(int idx)
{
    if (used[idx])
        return;
    used[idx] = 1;
    for (tlist * x = graph[idx]; x != NULL; x = x->next)
        rec(x->inf);
}


int main(int argc, char* argv[])
{
    freopen("minister.in", "rt", stdin);
    freopen("minister.out", "wt", stdout);

    memset(graph, 0, sizeof(graph));

    n = readint();
    m = readint();
    assert(1 <= n && n <= 4000);
    assert(1 <= m && m <= 100000);

    set <int> Set;

    forn(i, n)
    {
        d[i] = readint();
        assert(Set.count(d[i]) == 0);
        Set.insert(d[i]);
        assert(fabs(double(d[i])) <= 100000 + 1E-8);
    }

    forn(i, m)
    {
        int a, b, dab;
        a = readint(); b = readint(); dab = readint();
        assert(1 <= a && a <= n);
        assert(1 <= b && b <= n);
        assert(0 <= dab && dab <= 10000);
        a--, b--;
        listAdd(graph[a], b, dab); graph[a]->num = i;
        listAdd(graph[b], a, dab); graph[b]->num = i;
        change[i] = dab;
    }

    memset(used, 0, sizeof(used));
    rec(0);
    forn(i, n)
        assert(used[i]);

    memset(used, 0, sizeof(used));
    ans = 1;
    int ret = 0;

    for (;;)
    {
        int min = INF, pmin = -1;
        forn(i, n)
            if (!used[i] && min > d[i])
                min = d[i], pmin = i;
        if (min > INF / 2 || pmin == -1)
            break;
        used[pmin] = true;
        if (pmin != 0)
        {
            vector <tlist *> more_phi, less_phi, eq_phi;
            for (tlist * x = graph[pmin]; x != NULL; x = x->next)
                if (used[x->inf])
                {
                    int phi = d[pmin] - d[x->inf];
                    assert(phi > 0);
                    if (x->d > phi)
                        more_phi.pb(x);
                    if (x->d < phi)
                        less_phi.pb(x);
                    if (x->d == phi)
                        eq_phi.pb(x);
                }
            if (more_phi.size() + less_phi.size() + eq_phi.size() == 0)
            {
                ans = 0;
                break;
            }
            if (!less_phi.empty())
                forv(i, less_phi)
                {
                    change[less_phi[i]->num] += d[pmin] -
                        d[less_phi[i]->inf] - less_phi[i]->d;
                    ret += d[pmin] -
                        d[less_phi[i]->inf] - less_phi[i]->d;
                }
            else
            {
                set <pair<int, int> > edges;
                if (eq_phi.empty())
                {
                    int epmin = -1, emin = INF;
                    forv(i, more_phi)
                        edges.insert(make_pair(more_phi[i]->d - d[pmin] +
                            d[more_phi[i]->inf], i));
                    set <pair<int, int> >::iterator it =
                        edges.begin();
                    int size = edges.size();
                    int offset = std::min(random(size), random(size));
                    offset = std::min(offset, random(size));
                    if (offset >= size)
                        offset = size - 1;
                    forn(k, offset)
                        it++;
                    emin = it->first;
                    epmin = it->second;
                    change[more_phi[epmin]->num] -= emin;
                    ret += emin;
                }
            }
        }
    }

    forn(i, n)
        if (used[i] == 0 || ans == 0 || ret > INF / 2 || d[0] != 0)
        {
            cout << -1;
            return 0;
        }

    cout << ret << endl;
    forn(i, m)
        cout << change[i] << endl;

    return 0;
}