{$R+,Q+,S+}
{$apptype CONSOLE}
{,$define DEBUG}
{$MAXSTACKSIZE 160000000}

const
    MAX_V = 10000;
    MAX_E = 300000;

    IN_FILE = 'dfs.in';
    OUT_FILE = 'dfs.out';

type
    TColor = (_white, _gray, _black);

    TVertex = record
        firstout, firstin : integer;
        outdeg : integer;
        parent : integer;
        parentused : boolean;
        parente : integer;
        dseroot : integer;
        dserank : integer;
        lca : integer;
        prenext : integer;
        firstrout : integer;
        firstsout : integer;
        lastsout : integer;
    end;

    TEdge = record
        head, tail : integer;
        lca : integer;
        prehead, pretail : integer;
        treearc : boolean;
        crossarc : boolean;
        nextin, nextout : integer;
        nextrout : integer;
        nextsout : integer;
    end;

var
    nv : integer;
    v : array[1..MAX_V] of TVertex;
    ne : integer;
    e : array[1..MAX_E] of TEdge;

    visited : array[1..MAX_V] of boolean;
    colors : array[1..MAX_V] of TColor;

function DSERoot(i : integer) : integer;
var
    j, k : integer;

begin
    j := i;
    while v[i].dseroot <> i do
        i := v[i].dseroot;
    result := i;
    while j <> i do begin
        k := v[j].dseroot;
        v[j].dseroot := i;
        j := k;
    end;
end;

procedure DSEJoin(a, b : integer);
begin
    a := DSERoot(a);
    b := DSERoot(b);
    if v[a].dserank < v[b].dserank then
        v[a].dseroot := b
    else if v[a].dserank > v[b].dserank then
        v[b].dseroot := a
    else begin
        inc(v[a].dserank);
        v[b].dseroot := a;
    end;
end;

procedure DSEInit(i : integer);
begin
    v[i].dseroot := i;
    v[i].dserank := 0;
    v[i].lca := i;
end;

procedure LCADFS(i : integer);
var
    j : integer;

    procedure SetLCA(j, q : integer);
    var
        lca : integer;

    begin
        lca := v[DSERoot(q)].lca;
        if DSERoot(q) <> DSERoot(i) then begin
{$ifdef DEBUG}
            writeln('arc ', e[j].tail, '->', e[j].head, ' is cross arc, lca is ', lca);
{$endif}
            e[j].lca := lca;
            e[j].crossarc := true;
        end else begin
{$ifdef DEBUG}
            writeln('arc ', e[j].tail, '->', e[j].head, ' is not cross arc');
{$endif}
        end;
    end;

begin
{$ifdef DEBUG}
    writeln('lcadsf started at ', i);
{$endif}
    DSEInit(i);

    j := v[i].firstout;
    while j <> 0 do begin
        if e[j].treearc then begin
{$ifdef DEBUG}
            writeln('fetch tree arc ', i, '->', e[j].head);
{$endif}
            LCADFS(e[j].head);
            DSEJoin(i, e[j].head);
            v[DSERoot(i)].lca := i;
        end;
        j := e[j].nextout;
    end;

    j := v[i].firstout;
    while j <> 0 do begin
        if not e[j].treearc and visited[e[j].head] then
            SetLCA(j, e[j].head);
        j := e[j].nextout;
    end;

    j := v[i].firstin;
    while j <> 0 do begin
        if not e[j].treearc and visited[e[j].tail] then
            SetLCA(j, e[j].tail);
        j := e[j].nextin;
    end;

    visited[i] := true;
{$ifdef DEBUG}
    writeln('lcadsf finished at ', i);
{$endif}
end;

procedure PreLCADFS(i, parent : integer);
var
    j : integer;

begin
    if parent <> 0 then
        v[parent].prenext := i;

    j := v[i].firstout;
    while j <> 0 do begin
        if e[j].treearc then begin
            PreLCADFS(e[j].head, i);
        end;
        j := e[j].nextout;
    end;

    j := v[i].firstout;
    while j <> 0 do begin
        if e[j].crossarc then
            e[j].pretail := v[e[j].lca].prenext;
        j := e[j].nextout;
    end;

    j := v[i].firstin;
    while j <> 0 do begin
        if e[j].crossarc then
            e[j].prehead := v[e[j].lca].prenext;
        j := e[j].nextin;
    end;
end;

procedure DumpPreLCA;
var
    i, j : integer;

begin
    for i := 1 to nv do begin
        j := v[i].firstout;
        while j <> 0 do begin
            if e[j].crossarc then
                writeln('cross arc ', e[j].tail, '->', e[j].head, ' reduces to ',
                    e[j].pretail, '->', e[j].prehead);
            j := e[j].nextout;
        end;
    end;
end;

procedure BuildReducedGraph;
var
    i, j : integer;

begin
    for i := 1 to nv do begin
        j := v[i].firstout;
        while j <> 0 do begin
            if e[j].crossarc then begin
                e[j].nextrout := v[e[j].pretail].firstrout;
                v[e[j].pretail].firstrout := j;
            end;
            j := e[j].nextout;
        end;
    end;
end;

procedure NoSolution;
begin
    assign(output, OUT_FILE);
    rewrite(output);
    writeln('NO');
    close(output);
    halt;
end;

procedure SortDFS(i : integer);
var
    j, k : integer;

begin
    colors[i] := _gray;
    j := v[i].firstrout;
    while j <> 0 do begin
        if colors[e[j].prehead] = _gray then
            NoSolution;
        if colors[e[j].prehead] = _white then
            SortDFS(e[j].prehead);
        j := e[j].nextrout;
    end;

{$ifdef DEBUG}
    writeln('sortdfs finished at ', i);
{$endif}
    if i <> 1 then begin
        j := v[i].parent;
        k := v[i].parente;
        if v[j].firstsout = 0 then begin
            v[j].firstsout := k;
            v[j].lastsout := k;
        end else begin
            e[v[j].lastsout].nextsout := k;
            v[j].lastsout := k;
        end;
    end;

    colors[i] := _black;
end;

procedure Solve;
var
    i : integer;

begin
    fillchar(visited, sizeof (visited), false);
    LCADFS(1);
    PreLCADFS(1, 0);
{$ifdef DEBUG}
    DumpPreLCA;
{$endif}
    BuildReducedGraph;

    for i := 1 to nv do
        colors[i] := _white;
    for i := 1 to nv do
        if colors[i] = _white then
            SortDFS(i);
end;

procedure ReadData;
var
    i, j : integer;
    k, x : integer;

    procedure AppendArc(head, tail : integer);
    begin
        inc(ne);
        e[ne].head := head;
        e[ne].tail := tail;

        e[ne].treearc := (v[head].parent = tail) and not v[head].parentused;
        if e[ne].treearc then begin
            v[head].parentused := true;
            v[head].parente := ne;
        end;    
        e[ne].crossarc := false;
        e[ne].nextout := v[tail].firstout;
        v[tail].firstout := ne;
        e[ne].nextin := v[head].firstin;
        v[head].firstin := ne;
    end;

begin
    fillchar(v, sizeof (v), 0);
    fillchar(e, sizeof (e), 0);

    read(nv);
    v[1].parent := 0;
    for i := 1 to nv - 1 do
        read(v[i+1].parent);
    ne := 0;
    for i := 1 to nv do begin
        read(k);
        v[i].outdeg := k;
        for j := 1 to k do begin
            read(x);
            AppendArc(x, i);
        end;
    end;
end;

procedure WriteData;
var
    i, j : integer;

begin
    writeln('YES');
    for i := 1 to nv do begin
        write(v[i].outdeg);
        j := v[i].firstsout;
        while j <> 0 do begin
            write(' ', e[j].head);
            j := e[j].nextsout;
        end;
        write(' ');
        j := v[i].firstout;
        while j <> 0 do begin
            if not e[j].treearc then
                write(' ', e[j].head);
            j := e[j].nextout;
        end;
        writeln;
    end;
end;

begin
    assign(input, IN_FILE);
    reset(input);
    ReadData;
    close(input);

    Solve;

    assign(output, OUT_FILE);
    rewrite(output);
    WriteData;
    close(output);
end.
