/* by Michael R. Mirzayanov
 */
 
#include <iostream>
#include <set>
#include <algorithm>

using namespace std;

#define forn(i, n) for(int i = 0; i < (n); i++)
#define NMAX 12000
#define MMAX 120000

typedef int trow[NMAX];
typedef struct tlist
{
    int inf;
    int dir;
    tlist * next;
    tlist(int inf = 0, tlist * next = NULL) : inf(inf), next(next) { };
} tlist;

trow dsu;
trow dsu_r;
trow timex;

int n = 0, m = 0;

tlist * graph[NMAX];
tlist * tree[NMAX];
tlist * order[NMAX];

int timer;

typedef pair<int, int> ipair;
typedef set<ipair> ipairset;

ipair vtime[NMAX];
int depth[NMAX];
int ancestor[NMAX];
int visited[NMAX];

int path[NMAX + 1];
ipairset sets[NMAX];
int inverse[NMAX];

void listAdd(tlist * &l, int inf)
{
    tlist * x = new tlist(inf, l);
    x->next = l;
    l = x;
}

void dsuInit(trow &a, trow &r, int n)
{
    forn(i, n)
        a[i] = i,
        r[i] = 0;
}

int dsuLeader(trow &a, int c)
{
    if (a[c] != c)
        a[c] = dsuLeader(a, a[c]);
    return a[c];
}

bool dsuUnion(trow &a, trow &r, int idx1, int idx2)
{
    int l1 = dsuLeader(a, idx1), l2 = dsuLeader(a, idx2);
    if (l1 != l2)
        if (r[l1] < r[l2])
            a[l1] = l2, r[l2] += r[l1];
        else
            a[l2] = l1, r[l1] += r[l2];
    else
        return false;
    return true;
}

void rec(int idx, int d)
{
    timer++;
    vtime[idx].first = timer;
    depth[idx] = d;
    for(tlist * x = tree[idx]; x != NULL; x = x->next)
        rec(x->inf, d + 1);
    vtime[idx].second = timer;
}

bool is_like(int idx1, int idx2)
{
    return (vtime[idx1].first <= vtime[idx2].first
        && vtime[idx2].second <= vtime[idx1].second) ||
        (vtime[idx2].first <= vtime[idx1].first
        && vtime[idx1].second <= vtime[idx2].second);
}

void lca(int idx)
{
    path[++path[0]] = idx;
    timer++;
    visited[idx] = true;
    for(tlist * x = tree[idx]; x != NULL; x = x->next)
    {
        lca(x->inf);
        dsuUnion(dsu, dsu_r, idx, x->inf);
        ancestor[dsuLeader(dsu, idx)] = idx;
        sets[idx].insert(make_pair(vtime[x->inf].first, x->inf));
    }
    for (tlist * x = graph[idx]; x != NULL; x = x->next)
        if (!is_like(idx, x->inf) && visited[x->inf])
        {
            int __lca = ancestor[dsuLeader(dsu, x->inf)];
            int __lca_nxt_1 = path[depth[__lca] + 1 + 1];

            ipairset::iterator
                it = sets[__lca].lower_bound(make_pair(vtime[x->inf].first, NMAX));
            it--;
            int __lca_nxt_2 = it->second;

            if (x->dir == 1)
                listAdd(order[__lca_nxt_2], __lca_nxt_1);
            else
                listAdd(order[__lca_nxt_1], __lca_nxt_2);
        }
    path[0]--;
}

void tsort(int idx)
{
    if (visited[idx])
        return;
    visited[idx] = 1;
    for (tlist * x = order[idx]; x != NULL; x = x->next)
        tsort(x->inf);
    path[++path[0]] = idx;
}

int readint()
{
    char c = ' ';
    while (c < '0' || c > '9')
        c = getc(stdin);
    int result = 0;
    while (c >= '0' && c <= '9')
    {
        result = result * 10 + c - '0';
        c = getc(stdin);
    }
    return result;
}

int main(int argc, char* argv[])
{
    freopen("dfs.in", "rt", stdin);
    freopen("dfs.out", "wt", stdout);

    memset(tree, 0, sizeof(tree));
    memset(graph, 0, sizeof(graph));
    memset(order, 0, sizeof(order));

    ipairset tree_set;

    n = readint();
    forn(i, n)
        if (i > 0)
        {
            int p = readint() - 1;
            listAdd(tree[p], i); tree[p]->dir = +1;
            tree_set.insert(make_pair(p, i));
        }

    forn(i, n)
    {
        int k = readint();
        forn(j, k)
        {
            int b = readint() - 1;
            listAdd(graph[i], b); graph[i]->dir = +1;
            listAdd(graph[b], i); graph[b]->dir = -1;
        }
    }

    dsuInit(dsu, dsu_r, n);

    timer = 0;
    rec(0, 0);

    path[0] = 0;
    lca(0);

    path[0] = 0;
    memset(visited, 0, sizeof(visited));
    forn(i, n)
        if (!visited[i])
            tsort(i);
    forn(i, n)
        inverse[path[i + 1]] = i;

    forn(i, n)
        for (tlist * x = order[i]; x != NULL; x = x->next)
            if (inverse[i] < inverse[x->inf])
            {
                printf("NO\n");
                return 0;
            }
    printf("YES\n");

    ipair lst[MMAX];
    int c_lst = 0;

    forn(i, n)
    {
        c_lst = 0;
        for (tlist * x = graph[i]; x != NULL; x = x->next)
            if (x->dir == 1)
            {
                lst[c_lst++] = make_pair(NMAX - inverse[x->inf], x->inf);
                if (tree_set.count(make_pair(i, x->inf)) == 0)
                    lst[c_lst - 1].first = 2 * NMAX;
            }
        printf("%d", c_lst);
        sort(lst, lst + c_lst);
        forn(j, c_lst)
            printf(" %d", lst[j].second + 1);
        printf("\n");
    }

    return 0;
}