uses DieHard;
type
    TDirection=record
                     DX, DY: LongInt;
                     Invert: LongInt;
               end;
var
   Map: TMap;
   N, M: LongInt;
   DeltaX, DeltaY: LongInt;
   Directions: array [DIR_UP..DIR_LEFT] of TDirection;
   StartIsPossible: array [0..NMax, 0..NMax] of Boolean;
   States: array [0..NMax, 0..NMax] of Byte;
   Values: array [0..NMax, 0..NMax] of LongInt;
   From: array [0..NMax, 0..NMax] of Byte;
   SituationsLeft: LongInt;
   WayLength: LongInt;
   Way: array [0..NMax*NMax] of Byte;

procedure ReadData;
begin
     Init (N, M, Map);
end;

procedure NormalizeXY (var aX, aY: LongInt);
begin
     while aX<0
           do Inc (aX, M);
     aX:=aX mod M;
     while aY<0
           do Inc (aY, N);
     aY:=aY mod N;
end;

function CanTreasureBeHere: Boolean;
var
   StartX, StartY, RealX, RealY: LongInt;
begin
     for StartX:=0 to M-1
         do for StartY:=0 to M-1
                do if StartIsPossible [StartX, StartY]
                      then begin
                           RealX:=StartX+DeltaX;
                           RealY:=StartY+DeltaY;
                           NormalizeXY (RealX, RealY);
                           if Map [RealY, RealX]=MAP_T
                              then begin
                                   CanTreasureBeHere:=true;
                                   Exit;
                              end;
                      end;
     CanTreasureBeHere:=false;
end;

procedure LearnIceCell;
var
   StartX, StartY, RealX, RealY: LongInt;
begin
     for StartX:=0 to M-1
         do for StartY:=0 to N-1
                do if StartIsPossible [StartX, StartY]
                      then begin
                           RealX:=StartX+DeltaX;
                           RealY:=StartY+DeltaY;
                           NormalizeXY (RealX, RealY);
                           if Map [RealY, RealX]<>MAP_ICE
                              then begin
                                   StartIsPossible [StartX, StartY]:=false;
                                   Dec (SituationsLeft);
                              end;
                      end;
end;

procedure DFS;
var
   NDirection: LongInt;
   Direction: Byte;
   OldDeltaX, OldDeltaY: LongInt;
   Went: array [DIR_UP..DIR_LEFT] of Boolean;
begin
     States [DeltaX, DeltaY]:=1;
     OldDeltaX:=DeltaX;
     OldDeltaY:=DeltaY;
     NormalizeXY (OldDeltaX, OldDeltaY);

     if CanTreasureBeHere
        then Dig;
     FillChar (Went, SizeOf (Went), false);
     for NDirection:=DIR_UP to DIR_LEFT
         do begin
            Direction:=NDirection;

            OldDeltaX:=DeltaX;
            OldDeltaY:=DeltaY;
            DeltaX:=DeltaX+Directions [Direction].DX;
            DeltaY:=DeltaY+Directions [Direction].DY;
            NormalizeXY (DeltaX, DeltaY);
            if (DeltaX>=0) and (DeltaX<M) and (DeltaY>=0) and (DeltaY<=N)
               then case States [DeltaX, DeltaY] of
                         0: begin
                                 if DoMove (Direction)
                                    then begin
                                         LearnIceCell;
                                         if SituationsLeft=1
                                            then Exit;
                                    end;
                                 DFS;
                                 if SituationsLeft=1
                                    then Exit;
                                 DoMove (Directions [Direction].Invert);
                            end;
                    end;
            DeltaX:=OldDeltaX;
            DeltaY:=OldDeltaY;
         end;
     States [DeltaX, DeltaY]:=2;
end;

procedure Dijkstra;
var
   StartX, StartY, X, Y, BeginX, BeginY: LongInt;
   Direction: Byte;
   NewValue: LongInt;
begin
     FillChar (States, SizeOf (States), 0);
     for StartX:=0 to M-1
         do for StartY:=0 to N-1
                do if StartIsPossible [StartX, StartY]
                      then begin
                           BeginX:=StartX+DeltaX;
                           BeginY:=StartY+DeltaY;
                      end;
     NormalizeXY (BeginX, BeginY);
     States [BeginX, BeginY]:=1;
     FillChar (Values, SizeOf (Values), 0);
     repeat
           for StartX:=0 to M-1
               do begin
                  for StartY:=0 to N-1
                      do if States [StartX, StartY]=1
                            then Break;
                  if States [StartX, StartY]=1
                     then Break;
               end;
           if States [StartX, StartY]=1
              then begin
                   for X:=0 to M-1
                       do for Y:=0 to N-1
                              do if (States [X, Y]=1) and (Values [X, Y]<Values [StartX, StartY])
                                    then begin
                                         StartX:=X;
                                         StartY:=Y;
                                    end;
                   for Direction:=DIR_LEFT downto DIR_UP
                       do begin
                          NewValue:=Values [StartX, StartY];
                          X:=StartX+Directions [Direction].DX;
                          Y:=StartY+Directions [Direction].DY;
                          NormalizeXY (X, Y);
                          case Map [Y, X] of
                               MAP_ICE: Inc (NewValue, DMG_FALL);
                               MAP_EMPTY: Inc (NewValue, DMG_MOVE);
                          end;
                          if (States [X, Y]=0) or ((States [X, Y]=1) and (NewValue<Values [X, Y]))
                             then begin
                                  States [X, Y]:=1;
                                  From [X, Y]:=Direction;
                                  Values [X, Y]:=NewValue;
                             end;
                       end;
                   States [StartX, StartY]:=2;
              end
              else Break;
     until false;

     for StartX:=0 to M-1
         do for StartY:=0 to N-1
                do if Map [StartY, StartX]=MAP_T
                      then begin
                           X:=StartX;
                           Y:=StartY;
                      end;
     WayLength:=0;
     while (X<>BeginX) or (Y<>BeginY)
           do begin
              Inc (WayLength);
              Direction:=From [X, Y];
              Way [WayLength]:=Direction;
              StartX:=X+Directions [Directions [Direction].Invert].DX;
              StartY:=Y+Directions [Directions [Direction].Invert].DY;
              NormalizeXY (StartX, StartY);
              X:=StartX;
              Y:=StartY;
           end;
     for X:=WayLength downto 1
         do DoMove (Way [X]);
     Dig;
end;

procedure Solve;
var
   X, Y: LongInt;
begin
     RandSeed:=-110;
     DeltaX:=0;
     DeltaY:=0;
     with Directions [DIR_UP]
          do begin
             DX:=0;
             DY:=-1;
             Invert:=DIR_DOWN;
          end;
     with Directions [DIR_DOWN]
          do begin
             DX:=0;
             DY:=1;
             Invert:=DIR_UP;
          end;
     with Directions [DIR_LEFT]
          do begin
             DX:=-1;
             DY:=0;
             Invert:=DIR_RIGHT;
          end;
     with Directions [DIR_RIGHT]
          do begin
             DX:=1;
             DY:=0;
             Invert:=DIR_LEFT;
          end;
     SituationsLeft:=M*N;
     FillChar (StartIsPossible, SizeOf (StartIsPossible), true);
     for X:=0 to M-1
         do for Y:=0 to N-1
                do if Map [Y, X]=MAP_T
                      then begin
                           StartIsPossible [X, Y]:=false;
                           Dec (SituationsLeft);
                      end;
     FillChar (States, SizeOf (States), 0);
     DFS;
     Dijkstra;
end;

begin
     ReadData;
     Solve;
end.
