const
     FileIn='queen.in';
     FileOut='queen.out';
     MaxN=50;
     sQueenWins=-1;
     sDraw=0;
     sKingWins=1;
type
    TDirection=record
                     DX, DY: LongInt;
               end;
var
   N, M: LongInt;
   Forbidden: array [1..2, 1..MaxN, 1..2, 1..MaxN] of Boolean;

   Directions: array [1..8] of TDirection;

   WhoWins: Integer;
   AnswerStepsCount: LongInt;

procedure Forbid (aX1, aY1, aX2, aY2: LongInt);
begin
     if (aX1>=1) and (aX1<=2) and (aY1>=1) and (aY1<=N) and
        (aX2>=1) and (aX2<=2) and (aY2>=1) and (aY2<=N)
        then begin
             Forbidden [aX1, aY1, aX2, aY2]:=true;
             Forbidden [aX2, aY2, aX1, aY1]:=true;
        end;
end;

procedure ReadData;
var
   F: Text;
   NItem: LongInt;
   X1, Y1, X2, Y2: LongInt;
begin
     FillChar (Forbidden, SizeOf (Forbidden), false);
     Assign (F, FileIn);
     Reset (F);
     Readln (F, N, M);
     for NItem:=1 to M
         do begin
            Readln (F, X1, Y1, X2, Y2);
            Forbid (X1, Y1, X2, Y2);
            if Abs (Y1-Y2)=1
               then begin
                    Forbid (X1, Y1, X2-1, Y2);
                    Forbid (X1, Y1, X2+1, Y2);
                    Forbid (X1+1, Y1, X2, Y2);
                    Forbid (X1-1, Y1, X2, Y2);
               end
               else if Abs (X1-X2)=1
                       then begin
                            Forbid (X1, Y1, X2, Y2-1);
                            Forbid (X1, Y1, X2, Y2+1);
                            Forbid (X1, Y1+1, X2, Y2);
                            Forbid (X1, Y1-1, X2, Y2);
                       end;
         end;
     Close (F);
end;

procedure WriteData;
var
   F: Text;
begin
     Assign (F, FileOut);
     Rewrite (F);
     case WhoWins of
          sQueenWins: begin
                           Writeln (F, 'queen wins');
                           Writeln (F, AnswerStepsCount);
                      end;
          sKingWins: begin
                          Writeln (F, 'king wins');
                          Writeln (F, AnswerStepsCount);
                     end;
          sDraw: Writeln (F, 'draw');
     end;
     Close (F);
end;

function CanGo (aFromX, aFromY, aToX, aToY: LongInt): Boolean;
begin
     CanGo:=(aToX>=1) and (aToX<=2) and (aToY>=1) and (aToY<=N) and (not Forbidden [aFromX, aFromY, aToX, aToY]);
end;

type
    TCacheCell=record
                     Cached: Boolean;
                     Value: LongInt;
                     StepsCount: LongInt;
               end;
var
   Cache: array [1..2, 1..MaxN, 1..2, 1..MaxN, Boolean] of TCacheCell;
   States: array [1..2, 1..MaxN, 1..2, 1..MaxN, Boolean] of Boolean;

function EvalMinQueen (KX, KY, QX, QY: LongInt; var aStepsCount: LongInt): LongInt; forward;

function EvalMaxKing (KX, KY, QX, QY: LongInt; var aStepsCount: LongInt): LongInt;
var
   Mu: LongInt;
   NewX, NewY: LongInt;

procedure TryWithCache;
begin
     with Cache [NewX, NewY, QX, QY, true]
          do begin
             if not Cached
                then begin
                     Value:=EvalMinQueen (NewX, NewY, QX, QY, StepsCount);
                     Cached:=true;
                end;
             if aStepsCount=0
                then aStepsCount:=StepsCount+1;
             if Value>Mu
                then begin
                     aStepsCount:=StepsCount+1;
                     Mu:=Value;
                end
                else if Value=Mu
                        then case Value of
                                  sQueenWins: if aStepsCount<StepsCount+1
                                                 then aStepsCount:=StepsCount+1;
                                  sKingWins: if aStepsCount>StepsCount+1
                                                then aStepsCount:=StepsCount+1;
                             end;
          end;
end;

function Sign (aValue: LongInt): LongInt;
begin
     if aValue<0
        then Sign:=-1
        else if aValue>0
                then Sign:=1
                else Sign:=0;
end;

function WillStayAlive: Boolean;
var
   Direction: LongInt;
   SignX, SignY: LongInt;
   Went: Boolean;
begin
     SignX:=Sign (NewX-QX);
     SignY:=Sign (NewY-QY);
     for Direction:=Low (Directions) to High (Directions)
         do with Directions [Direction]
                 do if (SignX=DX) and (SignY=DY)
                       then Break;
     SignX:=QX;
     SignY:=QY;
     repeat
           Went:=CanGo (SignX, SignY, SignX+Directions [Direction].DX, SignY+Directions [Direction].DY);
           if Went
              then begin
                   SignX:=SignX+Directions [Direction].DX;
                   SignY:=SignY+Directions [Direction].DY;
                   if (SignX=NewX) and (SignY=NewY)
                      then begin
                           WillStayAlive:=false;
                           Exit;
                      end;
              end;
     until not Went;
     WillStayAlive:=true;
end;

var
   Direction: LongInt;
begin
     aStepsCount:=0;
     if States [KX, KY, QX, QY, true]
        then Mu:=sDraw
        else begin
             States [KX, KY, QX, QY, false]:=true;
             Mu:=sQueenWins;
             for Direction:=Low (Directions) to High (Directions)
                 do begin
                    NewX:=KX+Directions [Direction].DX;
                    NewY:=KY+Directions [Direction].DY;
                    if CanGo (KX, KY, NewX, NewY) and WillStayAlive
                       then TryWithCache;
                 end;
        end;
     EvalMaxKing:=Mu;
end;

function EvalMinQueen (KX, KY, QX, QY: LongInt; var aStepsCount: LongInt): LongInt;
var
   Mu: LongInt;
   NewX, NewY: LongInt;

procedure TryWithCache;
begin
     with Cache [NewX, NewY, QX, QY, false]
          do begin
             if not Cached
                then begin
                     Value:=EvalMaxKing (KX, KY, NewX, NewY, StepsCount);
                     Cached:=true;
                end;
             if aStepsCount=0
                then aStepsCount:=StepsCount+1;
             if Value<Mu
                then begin
                     aStepsCount:=StepsCount+1;
                     Mu:=Value;
                end
                else if Value=Mu
                        then case Value of
                                  sQueenWins: if aStepsCount>StepsCount+1
                                                 then aStepsCount:=StepsCount+1;
                                  sKingWins: if aStepsCount<StepsCount+1
                                                then aStepsCount:=StepsCount+1;
                             end;
          end;
end;

function WillStayAlive: Boolean;
begin
     WillStayAlive:=(Abs (KX-NewX)>1) or (Abs (KY-NewY)>1) or
                    Forbidden [KX, KY, NewX, NewY];
end;

var
   Direction: LongInt;
   Went: Boolean;
begin
     aStepsCount:=0;
     if States [KX, KY, QX, QY, false]
        then Mu:=sDraw
        else begin
             States [KX, KY, QX, QY, false]:=true;
             Mu:=sKingWins;
             for Direction:=Low (Directions) to High (Directions)
                 do begin
                    NewX:=QX;
                    NewY:=QY;
                    repeat
                          Went:=CanGo (NewX, NewY, NewX+Directions [Direction].DX, NewY+Directions [Direction].DY);
                          if Went
                             then begin
                                  NewX:=NewX+Directions [Direction].DX;
                                  NewY:=NewY+Directions [Direction].DY;
                                  if WillStayAlive
                                     then TryWithCache
                                     else Went:=false;
                             end;
                    until not Went;
                 end;
        end;
     EvalMinQueen:=Mu;
end;

procedure Solve;
begin
     with Directions [1]
          do begin
             DX:=-1;
             DY:=0;
          end;
     with Directions [2]
          do begin
             DX:=1;
             DY:=0;
          end;
     with Directions [3]
          do begin
             DX:=0;
             DY:=-1
          end;
     with Directions [4]
          do begin
             DX:=0;
             DY:=+1;
          end;
     with Directions [5]
          do begin
             DX:=-1;
             DY:=-1;
          end;
     with Directions [6]
          do begin
             DX:=+1;
             DY:=+1;
          end;
     with Directions [7]
          do begin
             DX:=-1;
             DY:=+1;
          end;
     with Directions [8]
          do begin
             DX:=+1;
             DY:=-1;
          end;
     FillChar (States, SizeOf (States), false);
     FillChar (Cache, SizeOf (Cache), 0);
     WhoWins:=EvalMaxKing (1, 1, 2, N, AnswerStepsCount);
end;

begin
     ReadData;
     Solve;
     WriteData;
end.
