{$apptype console}

{$R+,S+,I+,Q+,O-}

program template;
const
 eps = 1e-9;
 nmax = 20100;
 infinity = 1e50;
 cinfile = 'input.txt';
 coutfile = 'output.txt';
type
 int = integer;
 real = extended;
 tpoint = record
  x,y :int;
 end;
 tsegment = record
  a,b :tpoint;
 end;
 trealPoint = record
  x,y :real;
 end;
 trealSegment = record
  a,b :trealpoint;
 end;
 teventType = (_start,_finish);
 tevent = record
  p :trealPoint;
  number :int;
  ev :tEventType;
 end;
 pevent = ^tevent;
 theap = record
{  inf :real;}
  num :int;
 end;
 pheap = ^theap;
type
 tsystem = array [1..2,1..3] of real;  
const
 ld :tpoint = (x:0;y:0);
 rd :tpoint = (x:1;y:0);
 ru :tpoint = (x:1;y:1);
 lu :tpoint = (x:0;y:1);
 DividePoint :tpoint = (x:1;y:0);
var
 n,m,l :int;
 s :array [1..nmax] of tsegment;
 pr :array [1..2*nmax] of tRealSegment;
 events :array [1..4*nmax] of pevent;
 heap :array [1..2*nmax] of pheap;
 perm :array [1..2*nmax] of int;
 k :int;
 o :tpoint;
 ans :real;

procedure init;
begin
 randseed := 67890;
 ans := 0;
 fillchar (s,sizeof(s),0);
 fillchar (events,sizeof(events),0);
 fillchar (pr,sizeof(pr),0);
 fillchar (heap,sizeof(heap),0);
 fillchar (perm,sizeof(perm),0);
 k := 0;
end;

procedure readdata;
var i,j :int;
begin
 assign (input,cinfile);
 reset (input);
 read (n,m);
 read (o.x,o.y);
 for i := 1 to n do
  read (s[i].a.x,s[i].a.y,s[i].b.x,s[i].b.y);
 close (input);
end;

procedure outdata;
var i,j :int;
begin
 assign (output,coutfile);
 rewrite (output);
 writeln (ans:0:5);
 close (output);
end;

function less (a,b :tpoint):boolean;
begin
 less := a.x*b.y - a.y*b.x > 0
end;

procedure swapPoint (var a,b :tpoint);
var tmp :tpoint;
begin
 tmp := a;
 a := b;
 b := tmp;
end;

procedure swapPheap (var a,b :pheap);
var tmp :pheap;
begin
 tmp := a;
 a := b;
 b := tmp;
end; 

procedure swapPevent (var a,b :pevent);
var tmp :pevent;
begin
 tmp := a;
 a := b;
 b := tmp;
end; 

procedure addevent (p :trealpoint; number :int; ev :teventType);
begin
 inc(k);
 new (events[k]);
 events[k]^.p := p;
 events[k]^.number := number;
 events[k]^.ev := ev;
end;

procedure transform (var res :trealsegment; var p :tsegment);
begin
 res.a.x := 1.0*p.a.x;
 res.a.y := 1.0*p.a.y;
 res.b.x := 1.0*p.b.x;
 res.b.y := 1.0*p.b.y;
end;

procedure Divide (var s :tsegment; var s1,s2 :trealSegment);
var xx :real;
begin
 xx := s.a.x + s.a.y*(s.b.x - s.a.x)/(s.a.y - s.b.y);
 s1.a.x := 1.0*s.a.x;
 s1.a.y := 1.0*s.a.y;
 s1.b.x := xx;
 s1.b.y := 0.0;
 {======}
 s2.a := s1.b;
 s2.b.x := 1.0*s.b.x;
 s2.b.y := 1.0*s.b.y; 
end;

function WhatHalf (var d :tevent):byte;
begin
 if abs (d.p.y) < eps then
  begin
   if (d.p.x < 0) xor (d.ev = _start) then
    WhatHalf := 1
   else
    WhatHalf := 2;
   exit;
  end;
 if d.p.y > 0 then
  WhatHalf := 1
 else
  WhatHalf := 2; 
end;

function lessEvent (var a,b :tevent):boolean;
var q1,q2 :byte;
    product :real;
begin
 q1 := WhatHalf (a);
 q2 := WhatHalf (b);
 if not (q1 = q2) then
  lessEvent := (q1 < q2)
 else
  begin
   product := a.p.x*b.p.y - a.p.y*b.p.x;
   if abs(product) < eps then
    begin
     if (a.p.x)*(b.p.x) < 0 then
      lessEvent := (a.p.x < 0) xor (q1 = 1)
     else
      lessEvent := a.ev > b.ev; 
    end
   else
    lessEvent := product > 0;
  end;
end;

procedure sort (l,r :int);
var i,j :int;
    x :tevent;
begin
 i := l;
 j := r;
 x := events[l + random(r-l+1)]^;
 repeat
  while lessEvent (events[i]^,x) do
   inc(i);
  while lessEvent (x,events[j]^) do
   dec(j);
  if i <= j then
   begin
    swapPevent (events[i],events[j]);
    inc(i);
    dec(j);
   end;
 until i > j;
 if i < r then
  sort (i,r);
 if l < j then
  sort (l,j);
end;

function solveSystem (var a :tsystem; var res :tRealpoint):boolean;
var d :real;
begin
 d := a[1,1]*a[2,2] - a[2,1]*a[1,2];
 solveSystem := false;
 if abs (d) < eps then
  exit;
 solveSystem := true;
 res.x := (a[1,3]*a[2,2] - a[2,3]*a[1,2])/d;
 res.y := (a[1,1]*a[2,3] - a[2,1]*a[1,3])/d;
end;

function distation (p :trealpoint; num :int):real;
var s :tsystem;
    r :trealpoint;
begin
 distation := infinity;

 s[1,1] := p.x;
 s[1,2] := - (pr[num].b.x - pr[num].a.x);
 s[1,3] := pr[num].a.x;

 s[2,1] := p.y;
 s[2,2] := - (pr[num].b.y - pr[num].a.y);
 s[2,3] := pr[num].a.y;

 if not solvesystem (s,r) then
  exit;
 if r.y < - eps then
  exit;
 if r.y > 1 - eps then
  exit;
 if r.x < 0 then
  exit;
 distation := r.x*sqrt(sqr(p.x) + sqr(p.y));
end;

procedure sift (p :trealpoint; i :int);
var d1,d2 :real;
begin
 d1 := distation (p,heap[i]^.num);
 d2 := distation (p,heap[i shr 1]^.num);
 while (i > 1) and (d1 < d2 - eps) do
  begin
   swapPheap (heap[i],heap[i shr 1]);
   perm[heap[i]^.num] := i;
   perm[heap[i shr 1]^.num] := i shr 1;
   i := i shr 1;
   d1 := distation (p,heap[i]^.num);
   if i > 1 then
    d2 := distation (p,heap[i shr 1]^.num);
  end;
end;

procedure shit (p :trealpoint; i :int);
var j :int;
begin
 while (i <= l shr 1) do
  begin
   j := 2*i;
   if (j < l) and (distation (p,heap[j+1]^.num) < distation (p,heap[j]^.num)) then
    inc(j);
   if distation (p,heap[i]^.num) > distation (p,heap[j]^.num) + eps then
    begin
     swapPheap (heap[i],heap[j]);
     perm[heap[i]^.num] := i;
     perm[heap[j]^.num] := j;
     i := j;
    end
   else
    break;
  end;

end;

procedure processEvent (number :int);
var s :trealSegment;
    syst :tsystem;
    p1,p2,r1,r2 :trealPoint;

begin
 if events[number].ev = _start then
   sift (events[number].p,perm[events[number].number])
 else
   shit (events[number].p,perm[events[number].number]);
 s := pr[heap[1]^.num];
 syst[1,1] := s.a.y - s.b.y;
 syst[1,2] := s.b.x - s.a.x;
 syst[1,3] := syst[1,1]*s.a.x + syst[1,2]*s.a.y;
 {=========}
 syst[2,1] := events[number].p.y;
 syst[2,2] := -events[number].p.x;
 syst[2,3] := syst[2,1]*events[number].p.x + syst[2,2]*events[number].p.y;
 if not solveSystem (syst,r1) then
  begin
   writeln ('Botva');
   halt(123);
  end; 
 {=======}
 syst[2,1] := events[number+1].p.y;
 syst[2,2] := -events[number+1].p.x;
 syst[2,3] := syst[2,1]*events[number+1].p.x + syst[2,2]*events[number+1].p.y;
 if not solveSystem (syst,r2) then
  begin
   writeln ('Botva');
   halt(123);
  end; 
 ans := ans + abs(r1.x*r2.y - r2.x*r1.y)/2;
end;

procedure solve;
var i,j :int;
    s1,s2 :trealsegment;
begin
 s[n+1].a := ld; s[n+1].b := rd;
 s[n+2].a := rd; s[n+2].b := ru;
 s[n+3].a := ru; s[n+3].b := lu;
 s[n+4].a := lu; s[n+4].b := ld;
 for i := n+1 to n+4 do
  begin
   s[i].a.x := s[i].a.x*m;
   s[i].a.y := s[i].a.y*m;
   s[i].b.x := s[i].b.x*m;
   s[i].b.y := s[i].b.y*m;
  end;
 inc(n,4);
 for i := 1 to n do
  begin
   s[i].a.x := s[i].a.x - o.x;
   s[i].a.y := s[i].a.y - o.y;
   s[i].b.x := s[i].b.x - o.x;
   s[i].b.y := s[i].b.y - o.y;
  end; 
 for i := 1 to n do
  if less (s[i].b,s[i].a) then
   swapPoint (s[i].b,s[i].a);
 for i := 1 to n do
  if less (s[i].a,DividePoint) and less (DividePoint,s[i].b) then
   begin
    Divide (s[i],s1,s2);
    inc(l);
    pr[l] := s1;
    inc(l);
    pr[l] := s2;
   end
  else
   begin
    inc(l);
    transform (pr[l],s[i]);
   end;
 for i := 1 to l do
  if abs (pr[i].a.x*pr[i].b.y - pr[i].a.y*pr[i].b.x) > eps then
  begin
   addEvent (pr[i].a,i,_start);
   addEvent (pr[i].b,i,_finish);
  end;
 sort (1,k);
 for i := 1 to l do
  begin
   new (heap[i]);
   heap[i]^.num := i;
   perm[i] := i;
  end;
 for i := 1 to k-1 do
  processEvent(i);
end;

begin
 init;
 readdata;
 solve;
 outdata;
end.