{$R+,O-}
{$APPTYPE CONSOLE}

const
    inFile = 'tore.in';
    outFile = 'tore.out';

    maxN = 20;
    infinity = maxlongint div 2;

type
    TOrbit = record
        x, y : integer;
        cost0, cost1 : integer;
    end;

var
    m, n : integer;
    map : array[0..maxN-1,0..maxN-1] of boolean;
    orb : array[0..maxN-1,0..maxN-1] of integer;

    nFullOrbs : integer;
    orbs : array[1..maxN*maxN] of TOrbit;

    dcan : array[0..maxN*maxN,0..maxN*maxN*maxN*2] of boolean;
    dhow : array[0..maxN*maxN,0..maxN*maxN*maxN*2] of boolean;

    bestCost : integer;
    totalSum : integer;
    blueSum : integer;
    best, this : array[0..maxN-1,0..maxN-1] of boolean;

procedure DynProg(dx, dy : integer);
var
    i, j, k : integer;
    costSum, curCost, thisCost : integer;

    procedure Paint(x0, y0 : integer);
    var
        x, y : integer;

    begin
        x := x0;
        y := y0;
        repeat
            this[x,y] := true;
            x := (x + 2 * dx) mod m;
            y := (y + 2 * dy) mod n;
        until (x = x0) and (y = y0);
    end;

begin
    costSum := 0;
    for i := 1 to nFullOrbs do
        inc(costSum, orbs[i].cost0 + orbs[i].cost1);

    dcan[0,0] := true;
    for i := 1 to costSum do
        dcan[0,i] := false;

    for i := 1 to nFullOrbs do begin
        for j := 0 to costSum do begin
            dcan[i,j] := false;
            if (j - orbs[i].cost0 >= 0) and dcan[i-1,j - orbs[i].cost0] then begin
                dcan[i,j] := true;
                dhow[i,j] := false;
            end;
            if (j - orbs[i].cost1 >= 0) and dcan[i-1,j - orbs[i].cost1] then begin
                dcan[i,j] := true;
                dhow[i,j] := true;
            end;
        end;
    end;

    k := -1;
    thisCost := bestCost;
    for i := 0 to costSum do
        if dcan[nFullOrbs, i] then begin
            curCost := abs(i + blueSum - (totalSum - i - blueSum));
            if curCost < thisCost then begin
                k := i;
                thisCost := curCost;
            end;
        end;


    if k = -1 then
        exit;

    for j := nFullOrbs downto 1 do begin
        if dhow[j,k] then begin
            Paint((orbs[j].x + dx) mod m, (orbs[j].y + dy) mod n);
            dec(k, orbs[j].cost1);
        end else begin
            Paint(orbs[j].x, orbs[j].y);
            dec(k, orbs[j].cost0);
        end;
    end;

    bestCost := thisCost;
    best := this;
end;

procedure TryTranslate(dx, dy : integer);
var
    x, y, k : integer;

    function ProcessOrbit(x0, y0, dx, dy : integer) : boolean;
    var
        i, j, x, y, len, occ, cost0, cost1 : integer;

    begin
        len := 0;
        occ := 0;
        cost0 := 0;
        cost1 := 0;
        x := x0;
        y := y0;
        while orb[x,y] = -1 do begin
            orb[x,y] := k;

            if odd(len) then
                inc(cost1, x + y)
            else
                inc(cost0, x + y);
            inc(len);

            if map[x,y] then
                inc(occ);

            x := (x + dx) mod m;
            y := (y + dy) mod n;
        end;

        if occ = len then begin
            if not odd(len) then begin
                inc(nFullOrbs);
                orbs[nFullOrbs].x := x0;
                orbs[nFullOrbs].y := y0;
                orbs[nFullOrbs].cost0 := cost0;
                orbs[nFullOrbs].cost1 := cost1;
                result := true;
            end else
                result := false;
            exit;
        end;

        x := x0;
        y := y0;
        for i := 1 to len do begin
            if not map[x,y] then
                break;
            x := (x + dx) mod m;
            y := (y + dy) mod n;
        end;

        j := 0;
        for i := 1 to len + 1 do begin
            if not map[x,y] then begin
                if odd(j) then begin
                    result := false;
                    exit;
                end;
                j := 0;
            end else begin
                if not odd(j) then begin
                    this[x,y] := true;
                    inc(blueSum, x + y);
                end;
                inc(j);
            end;
            x := (x + dx) mod m;
            y := (y + dy) mod n;
        end;

        result := true;
    end;

begin
    fillchar(orb, sizeof(orb), -1);
    fillchar(this, sizeof(this), false);
    k := 0;
    nFullOrbs := 0;
    blueSum := 0;
    for x := 0 to m - 1 do
        for y := 0 to n - 1 do
            if orb[x,y] = -1 then begin
                if not ProcessOrbit(x, y, dx, dy) then
                begin
                    blueSum := 0;
                    exit;
                end;
                inc(k);
            end;

    DynProg(dx, dy);
end;

procedure Solve;
var
    dx, dy : integer;

begin
    bestCost := infinity;
    for dx := 0 to m - 1 do
        for dy := 0 to n - 1 do
            TryTranslate(dx, dy);
end;

procedure ReadData;
var
    i, k, x, y : integer;

begin
    assign(input, inFile);
    reset(input);

    read(m, n, k);
    if (m < 1) or (m > maxN) or (n < 1) or (n > maxN) then
        runerror(239);

    fillchar(map, sizeof(map), false);
    totalSum := 0;
    for i := 1 to k do begin
        read(x, y);
        if (x < 0) or (x >= m) or (y < 0) or (y >= n) then
            runerror(239);
        if map[x,y] then
            runerror(239);
        inc(totalSum, x + y);
        map[x,y] := true;
    end;

    close(input);
end;

procedure WriteData;
var
    i, j, k : integer;

begin
    assign(output, outFile);
    rewrite(output);

    if bestCost >= infinity then begin
        writeln(-1);
    end else begin
        k := 0;
        for i := 0 to m - 1 do
            for j := 0 to n - 1 do
                if best[i,j] then
                    inc(k);
        writeln(k);
        for i := 0 to m - 1 do
            for j := 0 to n - 1 do
                if best[i,j] then
                    writeln(i, ' ', j);
    end;

    close(output);
end;

begin
    ReadData;
    Solve;
    WriteData;
end.
