#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#define NN 150
#define eps 1e-3
#define MANY 1700000000.0

struct POINT {
  int x,y;
};

struct POINTF {
  double x,y;
};

FILE *fi, *fo;
int n=0,m;
POINTF v[NN];
POINT a[NN];
bool good[NN];
double g[NN][NN];
double gg[NN][NN];
int st;
double btime;
POINTF pp;

double max(double a, double b)
{
  return (a>b)?a:b;
}

double min(double a, double b)
{
  return (a<b)?a:b;
}

int findpoint(POINTF p)
{
  int i;
  for(i=0;i<n;i++)
    if((fabs(v[i].x-p.x)<eps)&&(fabs(v[i].y-p.y)<eps))
      return i;
  v[n++]=p;
  return n-1;
}

double burntm(int x, int y)
{
  double aa,bb;
  double tm;
  if(gg[x][y]>=MANY)
    return max(g[st][x],g[st][y]);
  aa=g[st][x];
  bb=g[st][y];
  if(aa>bb)
  {
    bb=g[st][x];
    aa=g[st][y];
  }
  if(bb-aa+eps>(double)gg[x][y])
    return bb;
  tm=bb+((double)gg[x][y]-(bb-aa))/2.0;
  return tm;
}

void floid()
{
  int i,j,k;
  for(k=0;k<n;k++)
    for(i=0;i<n;i++)
      for(j=0;j<n;j++)
        if(g[i][j]>g[i][k]+g[k][j])
          g[i][j]=g[i][k]+g[k][j];
}

bool intersect(int x1, int x2, int y1, int y2, POINTF *p)
{
  if(fabs(v[x1].x-v[x2].x)<eps)
    return false;
  if(fabs(v[x1].y-v[x2].y)<eps)
    return false;
  if(fabs(v[y1].x-v[y2].x)<eps)
    return false;
  if(fabs(v[y1].y-v[y2].y)<eps)
    return false;
  if(v[x1].x-eps>v[x2].x)
    return intersect(x2,x1,y1,y2,p);
  if(v[y1].x-eps>v[y2].x)
    return intersect(x1,x2,y2,y1,p);
  if(fabs(v[x1].x-v[y1].x)>eps)
    return false;
  if(fabs(v[x2].x-v[y2].x)>eps)
    return false;
  if(fabs(v[x1].y-v[y2].y)>eps)
    return false;
  if(fabs(v[x2].y-v[y1].y)>eps)
    return false;
  p->x=(v[x1].x+v[x2].x)/2.0;
  p->y=(v[x1].y+v[x2].y)/2.0;
  return true;
}

void buildg()
{
  int i,j;
  double t;
  int aa,bb;
  POINTF p1,p2;
  for(i=0;i<NN;i++)
    for(j=0;j<NN;j++)
      g[i][j]=MANY;
  for(i=0;i<m;i++)
  {
    fscanf(fi,"%lf%lf%lf%lf%lf",&p1.x,&p1.y,&p2.x,&p2.y,&t);
    aa=findpoint(p1);
    bb=findpoint(p2);
    good[aa]=true;
    good[bb]=true;
    a[i].x=aa;
    a[i].y=bb;
    g[aa][bb]=t;
    g[bb][aa]=t;
  }
  for(i=0;i<m;i++)
  {
    for(j=0;j<m;j++)
    {
      if(intersect(a[i].x,a[i].y,a[j].x,a[j].y,&p1))
      {
        aa=findpoint(p1);
        good[aa]=false;
        g[a[i].x][aa]=g[a[i].x][a[i].y]/2.0;
        g[aa][a[i].x]=g[a[i].x][a[i].y]/2.0;
        g[a[i].y][aa]=g[a[i].x][a[i].y]/2.0;
        g[aa][a[i].y]=g[a[i].x][a[i].y]/2.0;
        g[a[j].x][aa]=g[a[j].x][a[j].y]/2.0;
        g[aa][a[j].x]=g[a[j].x][a[j].y]/2.0;
        g[a[j].y][aa]=g[a[j].x][a[j].y]/2.0;
        g[aa][a[j].y]=g[a[j].x][a[j].y]/2.0;
      }
    }
  }
  for(i=0;i<n;i++)
    g[i][i]=0.0;
  for(i=0;i<n;i++)
    for(j=0;j<n;j++)
      gg[i][j]=g[i][j];
  floid();
}

int findmed(int x, int y)
{
  POINTF p;
  int i,j;
  p.x=(v[x].x+v[y].x)/2.0;
  p.y=(v[x].y+v[y].y)/2.0;
  i=n;
  j=findpoint(p);
  n=i;
  if(j>=n)
    return -1;
  else
    return j;
}

double findbtime()
{
  int i,j;
  double tm=0;
  double t1,t2,t3;
  for(i=0;i<m;i++)
  {
    j=findmed(a[i].x,a[i].y);
    if(j<0)
    {
      tm=max(tm,burntm(a[i].x,a[i].y));
    }
    else
    {
      t1=burntm(a[i].x,a[i].y);
      t2=burntm(a[i].x,j);
      t3=burntm(a[i].y,j);
      tm=max(tm,min(t1,max(t2,t3)));
    }
  }
  return tm;
}

void solv()
{
  int i;
  double tm;
  buildg();
  btime=1700000000.0;
  for(i=0;i<n;i++)
  {
    if(good[i])
    {
      st=i;
      tm=findbtime();
      if(tm<btime)
      {
        btime=tm;
        pp=v[i];
      }
    }
  }
  pp.x+=eps;
  pp.y+=eps;
  fprintf(fo,"%0.0lf %0.0lf\n%0.2lf\n",pp.x,pp.y,btime);
}

int main()
{
  fi=fopen("f.in","rt");
  fo=fopen("f.out","wt");

  fscanf(fi,"%d",&m);
  solv();
  
  fclose(fi);
  fclose(fo);
  return 0;
}



