#define ONLINE
//#define DEBUG
#include <stdio.h>

#define INF 0x7FFFFF00l

#define MAX(x,y) (((x)>=(y))?(x):(y))
#define MIN(x,y) (((x)<=(y))?(x):(y))

struct TPoint {
  short x,y;
  char prime;
  inline TPoint operator+(const TPoint) const;
  inline int operator<(const TPoint) const;
  inline int operator!=(const TPoint) const;
};
struct TMatchRaw {
  TPoint a,b;
  long time;
};
struct TMatch {
  short a,b;
  long time;
  char remains;
};

class TFigure {
  private:
    short n_matches,n_points_max,c_points;
    TMatchRaw*matches_raw;
    TPoint*points;
    TMatch*matches;
    short c_matches_left;
    long time,*lighttimes,*blametimes;
    long blametime(short);
    void fire(short);
    void heapify(TPoint*,const short,const short);
    void sort(TPoint*,const short);
    short resolve(const TPoint);
  protected:
    long*times;
    long trypoint(short);
  public:
    TFigure(void);
    ~TFigure();
    void Create(void);
    void Delete(void);
    void scan(void);
    void printmin(void);
    void transform(void);
    void tryall(void);
};

TFigure figure;

int main(void) {
  #ifdef ONLINE
  freopen("f.in","rt",stdin);
  freopen("f.out","wt",stdout);
  #endif
  figure.scan();
  figure.transform();
  figure.tryall();
  figure.printmin();
  #ifdef ONLINE
  fclose(stdin);
  fclose(stdout);
  #endif
  return(0);
}


long TFigure::blametime(short match) {
  long light_a,light_b,matchtime;
  light_a=lighttimes[matches[match].a]; light_b=lighttimes[matches[match].b];
  matchtime=matches[match].time;
  long time_a,time_b,time_one,time_both,time_best;
  if (light_a<INF) {
    time_a=light_a+matchtime+matchtime;
  } else time_a=INF;
  if (light_b<INF) {
    time_b=light_b+matchtime+matchtime;
  } else time_b=INF;
  if ((light_a<INF)&&(light_b<INF)) {
    time_both=((light_a+light_b)>>1)+matchtime;
  } else time_both=INF;
  time_one=MIN(time_a,time_b);
  time_best=MIN(time_one,time_both);
  return(time_best);
}
void TFigure::fire(short match) {
  if (lighttimes[matches[match].a]>time) lighttimes[matches[match].a]=time;
  if (lighttimes[matches[match].b]>time) lighttimes[matches[match].b]=time;
  matches[match].remains=0;
}
long TFigure::trypoint(short start) {
  short i_point,i_match;
  for (i_point=0; i_point<c_points; i_point++) lighttimes[i_point]=INF;
  lighttimes[start]=0;
  for (i_match=0; i_match<n_matches; i_match++) matches[i_match].remains=1;
  c_matches_left=n_matches;
  time=0;
  while (c_matches_left>0) {
    for (i_match=0; i_match<n_matches; i_match++)
      if (matches[i_match].remains) blametimes[i_match]=blametime(i_match);
    short i_match_first;
    for (i_match_first=0; i_match_first<n_matches; i_match_first++)
      if (matches[i_match_first].remains) if (blametimes[i_match_first]<INF)
      break;
    if (i_match_first>=n_matches) break;
    time=blametimes[i_match_first];
    for (i_match=0; i_match<n_matches; i_match++)
      if (matches[i_match].remains) if (blametimes[i_match]<time)
    { i_match_first=i_match; time=blametimes[i_match]; }
    fire(i_match_first);
  }
  return(times[start]=time);
}


void TFigure::scan(void) {
  Delete();
  scanf("%hd",&n_matches);
  n_matches<<=1; n_points_max=n_matches<<1;
  Create();
  short i_match;
  for (i_match=0; i_match<n_matches; ) {
    TPoint a,b,c; long time;
    scanf("%hd%hd%hd%hd%ld",&a.x,&a.y,&b.x,&b.y,&time);
    c=a+b; a=a+a; b=b+b;
    a.prime=1; b.prime=1; c.prime=0;
    matches_raw[i_match].a=a; matches_raw[i_match].b=c;
    matches_raw[i_match++].time=time;
    matches_raw[i_match].a=b; matches_raw[i_match].b=c;
    matches_raw[i_match++].time=time;
  }
}
void TFigure::printmin(void) {
  short point_best,i_point;
  long time_best=INF;
  for (i_point=0; i_point<c_points; i_point++)
    if (times[i_point]<time_best)
    { point_best=i_point; time_best=times[i_point]; }
  printf("%hd %hd\n%.2Lf\n",points[point_best].x/2,points[point_best].y/2,
    ((long double)time_best)/4);
}
void TFigure::transform(void) {
  short i_match,c_points_all,i_point;
  c_points_all=0;
  for (i_match=0; i_match<n_matches; i_match++) {
    points[c_points_all++]=matches_raw[i_match].a;
    points[c_points_all++]=matches_raw[i_match].b;
  }
  sort(points,c_points_all);
  if (c_points_all>0) {
    for (c_points=i_point=1; i_point<c_points_all; i_point++)
    if (points[i_point]!=points[c_points-1])
    points[c_points++]=points[i_point];
  } else c_points=0;
  #ifdef DEBUG
  printf("%hd of %hd\n",c_points,c_points_all);
  for (i_point=0; i_point<c_points; i_point++)
  printf("%hd %hd\n",points[i_point].x,points[i_point].y);
  #endif
  for (i_match=0; i_match<n_matches; i_match++) {
    matches[i_match].a=resolve(matches_raw[i_match].a);
    matches[i_match].b=resolve(matches_raw[i_match].b);
    matches[i_match].time=matches_raw[i_match].time;
  }
  #ifdef DEBUG
  printf("%hd\n",n_matches);
  for (i_match=0; i_match<n_matches; i_match++)
  printf("%hd (%hd;%hd) %hd (%hd;%hd) %ld\n",
  matches[i_match].a,points[matches[i_match].a].x,points[matches[i_match].a].y,
  matches[i_match].b,points[matches[i_match].b].x,points[matches[i_match].b].y,
  matches[i_match].time);
  #endif
}
void TFigure::tryall(void) {
  short i_point;
  #ifdef DEBUG
  printf("...\n");
  #endif
  for (i_point=0; i_point<c_points; i_point++) if (points[i_point].prime) {
    trypoint(i_point);
    #ifdef DEBUG
    printf("%hd (%hd;%hd) : %ld\n",
    i_point,points[i_point].x,points[i_point].y,times[i_point]);
    #endif
  } else times[i_point]=INF;
}


void TFigure::heapify(TPoint*a,const short v,const short w) {
  short i,j; TPoint z;
  i=v; j=(v<<1)+1;
  if ((j<w)&&(a[j]<a[j+1])) j++;
  z=a[i];
  while ((j<=w)&&(z<a[j])) {
    a[i]=a[j];
    i=j; j=(j<<1)+1;
    if ((j<w)&&(a[j]<a[j+1])) j++;
  }
  a[i]=z;
}
void TFigure::sort(TPoint*a,const short n) {
  short i,j; TPoint z;
  for (j=n-1,i=n>>1; i>0; i--) heapify(a,i,j);
  for (; j>0; j--) {
    heapify(a,i,j);
    z=a[i]; a[i]=a[j]; a[j]=z;
  }
}
short TFigure::resolve(const TPoint arg) {
  short left,right,mid;
  for (left=0,right=c_points; left<right; ) {
    mid=(left+right)>>1;
    if (points[mid]<arg) left=mid+1; else right=mid;
  }
  return(left);
}


TFigure::TFigure(void) {
  matches_raw=0; points=0; matches=0;
  times=0;
  lighttimes=0; blametimes=0;
}
TFigure::~TFigure() {
  Delete();
}
void TFigure::Create(void) {
  matches_raw=new TMatchRaw[n_matches];
  points=new TPoint[n_points_max];
  matches=new TMatch[n_matches];
  times=new long[n_points_max];
  lighttimes=new long[n_points_max];
  blametimes=new long[n_matches];
}
void TFigure::Delete(void) {
  if (matches_raw) delete[]matches_raw;
  if (points) delete[]points;
  if (matches) delete[]matches;
  if (times) delete[]times;
  if (lighttimes) delete[]lighttimes;
  if (blametimes) delete[]blametimes;
}


TPoint TPoint::operator+(const TPoint arg) const {
  TPoint res;
  res.x=x+arg.x;
  res.y=y+arg.y;
  return(res);
}
int TPoint::operator<(const TPoint arg) const {
  if (x<arg.x) return(1); if (x>arg.x) return(0);
  if (y<arg.y) return(1); if (y>arg.y) return(0);
  return(0);
}
int TPoint::operator!=(const TPoint arg) const {
  return((x!=arg.x)||(y!=arg.y));
}


