const
     FileIn='f.in';
     FileOut='f.out';
     MaxN=40;
     MaxNodes=MaxN*2;
     MaxEdges=MaxNodes*2;
     Eps=1e-7;
type
    TEdge=record
                Index1, Index2: LongInt;
                T: Extended;
                Broken: Boolean;
          end;
    TNode=record
                X, Y: Extended;
                IsCrossing: Boolean;
          end;
var
   N: LongInt;
   EdgesCount: LongInt;
   Edges: array [1..MaxN] of TEdge;
   NodesCount: LongInt;
   Nodes: array [1..MaxNodes] of TNode;

   State: array [1..MaxEdges] of Byte;
   Progress: array [1..MaxEdges] of Extended;
   Visited: array [1..MaxNodes] of Boolean;

   AnswerX, AnswerY: LongInt;
   AnswerTime: Extended;

function GetNodeByXY (aX, aY: Extended): LongInt;
var
   NNode: LongInt;
begin
     for NNode:=1 to NodesCount
         do if (Abs (Nodes [NNode].X-aX)<Eps) and (Abs (Nodes [NNode].Y-aY)<Eps)
               then begin
                    GetNodeByXY:=NNode;
                    Exit;
               end;
     Inc (NodesCount);
     Nodes [NodesCount].X:=aX;
     Nodes [NodesCount].Y:=aY;
     Nodes [NodesCount].IsCrossing:=(Abs (aX-Trunc (aX))>Eps) or (Abs (aY-Trunc (aY))>Eps);
     GetNodeByXY:=NodesCount;
end;

procedure ConnectIndexes (aIndex1, aIndex2: LongInt; aT: Extended);
begin
     Inc (EdgesCount);
     Edges [EdgesCount].Index1:=aIndex1;
     Edges [EdgesCount].Index2:=aIndex2;
     Edges [EdgesCount].T:=aT;
     Edges [EdgesCount].Broken:=false;
end;

procedure Connect (X1, Y1, X2, Y2, T: Extended);
begin
     ConnectIndexes (GetNodeByXY (X1, Y1), GetNodeByXY (X2, Y2), T);
end;

function AlreadyConnected (aIndex1, aIndex2: LongInt): Boolean;
var
   NEdge: LongInt;
begin
     for NEdge:=1 to EdgesCount
         do if ((Edges [NEdge].Index1=aIndex1) and (Edges [NEdge].Index2=aIndex2)) or
               ((Edges [NEdge].Index1=aIndex2) and (Edges [NEdge].Index2=aIndex1))
               then begin
                    AlreadyConnected:=true;
                    Exit;
               end;
     AlreadyConnected:=false;
end;

procedure ConnectIndexesIfNeeded (aIndex1, aIndex2: LongInt; aT: Extended);
begin
     if not AlreadyConnected (aIndex1, aIndex2)
        then ConnectIndexes (aIndex1, aIndex2, aT);
end;

procedure ReadData;
var
   F: Text;
   NEdge: LongInt;
   X1, Y1, X2, Y2, T: LongInt;
begin
     Assign (F, FileIn);
     Reset (F);
     NodesCount:=0;
     Readln (F, N);
     for NEdge:=1 to N
         do begin
            Read (F, X1, Y1, X2, Y2, T);
            Connect (X1, Y1, X2, Y2, T);
         end;
     Close (F);
end;

procedure WriteData;
var
   F: Text;
begin
     Assign (F, FileOut);
     Rewrite (F);
     Writeln (F, AnswerX, #32, AnswerY);
     Writeln (F, AnswerTime:0:2);
     Close (F);
end;

procedure Cross;
var
   NEdge1, NEdge2: LongInt;
   MX, MY: Extended;
   MIndex: LongInt;
begin
     for NEdge1:=1 to N
         do for NEdge2:=NEdge1+1 to N
                do if (Nodes [Edges [NEdge1].Index1].X+Nodes [Edges [NEdge1].Index2].X=Nodes [Edges [NEdge2].Index1].X+Nodes [Edges [NEdge2].Index2].X) and
                      (Nodes [Edges [NEdge1].Index1].Y+Nodes [Edges [NEdge1].Index2].Y=Nodes [Edges [NEdge2].Index1].Y+Nodes [Edges [NEdge2].Index2].Y) and
                      (not (Edges [NEdge1].Broken or Edges [NEdge2].Broken))
                      then begin
                           MX:=(Nodes [Edges [NEdge1].Index1].X+Nodes [Edges [NEdge1].Index2].X)/2;
                           MY:=(Nodes [Edges [NEdge1].Index1].Y+Nodes [Edges [NEdge1].Index2].Y)/2;
                           MIndex:=GetNodeByXY (MX, MY);
                           ConnectIndexes (MIndex, Edges [NEdge1].Index1, Edges [NEdge1].T/2);
                           ConnectIndexes (MIndex, Edges [NEdge1].Index2, Edges [NEdge1].T/2);
                           ConnectIndexes (MIndex, Edges [NEdge2].Index1, Edges [NEdge2].T/2);
                           ConnectIndexes (MIndex, Edges [NEdge2].Index2, Edges [NEdge2].T/2);
                           Edges [NEdge1].Broken:=true;
                           Edges [NEdge2].Broken:=true;
                      end;
end;

procedure VisitNode (aIndex: LongInt);
var
   NEdge: LongInt;
begin
     for NEdge:=1 to EdgesCount
         do if (not Edges [NEdge].Broken) and (State [NEdge]<>4)
               then if Edges [NEdge].Index1=aIndex
                       then begin
                            if State [NEdge] and 1=0
                               then State [NEdge]:=State [NEdge] or 1
                       end
                       else if Edges [NEdge].Index2=aIndex
                               then if State [NEdge] and 2=0
                                       then State [NEdge]:=State [NEdge] or 2;
     Visited [aIndex]:=true;
end;

function BurnSpeed (aEdge: LongInt): LongInt;
var
   Speed: LongInt;
begin
     Speed:=2;
     if State [aEdge] and 1=0
        then Dec (Speed);
     if State [aEdge] and 2=0
        then Dec (Speed);
     BurnSpeed:=Speed;
end;

procedure Fire (aStartIndex: LongInt);
var
   TimeElapsed: Extended;
   DeltaTime, BestDeltaTime: Extended;
   NEdge: LongInt;
   Speed: LongInt;
begin
     TimeElapsed:=0;
     VisitNode (aStartIndex);
     repeat
           BestDeltaTime:=0;
           for NEdge:=1 to EdgesCount
               do if not Edges [NEdge].Broken
                     then begin
                          Speed:=BurnSpeed (NEdge);
                          if Speed>0
                             then begin
                                  DeltaTime:=(Edges [NEdge].T-Progress [NEdge])/Speed;
                                  if (DeltaTime<BestDeltaTime) or (BestDeltaTime<Eps)
                                     then BestDeltaTime:=DeltaTime;
                             end;
                     end;
           TimeElapsed:=TimeElapsed+BestDeltaTime;
           for NEdge:=1 to EdgesCount
               do if not Edges [NEdge].Broken
                     then begin
                          Speed:=BurnSpeed (NEdge);
                          if Speed>0
                             then begin
                                  Progress [NEdge]:=Progress [NEdge]+Speed*BestDeltaTime;
                                  if Abs (Progress [NEdge]-Edges [NEdge].T)<Eps
                                     then State [NEdge]:=4;
                             end;
                     end;
           for NEdge:=1 to EdgesCount
               do if State [NEdge]=4
                     then begin
                          if not Visited [Edges [NEdge].Index1]
                             then VisitNode (Edges [NEdge].Index1);
                          if not Visited [Edges [NEdge].Index2]
                             then VisitNode (Edges [NEdge].Index2);
                     end;
     until BestDeltaTime<Eps;
     if (AnswerTime<Eps) or (TimeElapsed<AnswerTime)
        then begin
             AnswerTime:=TimeElapsed;
             AnswerX:=Round (Nodes [aStartIndex].X);
             AnswerY:=Round (Nodes [aStartIndex].Y);
        end;
end;

procedure Solve;
var
   NNode: LongInt;
begin
     Cross;
     for NNode:=1 to NodesCount
         do if not Nodes [NNode].IsCrossing
               then begin
                    FillChar (State, SizeOf (State), 0);
                    FillChar (Progress, SizeOf (Progress), 0);
                    FillChar (Visited, SizeOf (Visited), 0);
                    Fire (NNode);
               end;
end;

begin
     ReadData;
     Solve;
     WriteData;
end.
