#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#define eps 1e-7
#define NN 21100

struct POINT {
  double x,y;
};

struct ANG {
  POINT a,b;
};

FILE *fi, *fo;
int n,m;
int k;
POINT st;
POINT ax[NN];
POINT ay[NN];
ANG b[2*NN];

double vp(POINT a, POINT b)
{
  return a.x*b.y-a.y*b.x;
}

double vp(ANG *a)
{
  return vp(a->a,a->b);
}

double s(ANG *a)
{
  return fabs(vp(a->a,a->b))/2.0;
}

bool isin(ANG *a, POINT p)
{
  ANG a1,a2,a3;
  a1.a=a->a;
  a1.b=p;
  a2.a=p;
  a2.b=a->b;
  a3.a.x=a->a.x-p.x;
  a3.a.y=a->a.y-p.y;
  a3.b.x=a->b.x-p.x;
  a3.b.y=a->b.y-p.y;
  if(s(a)>s(&a1)+s(&a2)+s(&a3)-eps)
    return true;
  return false;
}

void make_good(ANG *a)
{
  POINT t;
  if(vp(a)<0)
  {
    t=a->a;
    a->a=a->b;
    a->b=t;
  }
}

bool divide(ANG *a, POINT *p, ANG *r1, ANG *r2)
{
  double dd,dt,t,dl,l;
  POINT r;
  dd=(a->a.y-a->b.y)*p->x-(a->a.x-a->b.x)*p->y;
  dt=(a->a.y-a->b.y)*a->b.x-(a->a.x-a->b.x)*a->b.y;
  dl=-a->b.y*p->x+a->b.x*p->y;
  if(fabs(dd)<eps)
    return false;
  l=dl/dd;
  if(l<-eps)
    return false;
  if(l>1+eps)
    return false;
  t=dt/dd;
  if(t<-eps)
    return false;
  r.x=t*p->x;
  r.y=t*p->y;
  r1->a=a->a;
  r1->b=r;
  r2->a=r;
  r2->b=a->b;
  return true;
}

bool inter(ANG *a, ANG *b, POINT *p)
{
  double dd,dl,l,dt,t;
  dd=(a->a.x-a->b.x)*(b->b.y-b->a.y)-(a->a.y-a->b.y)*(b->b.x-b->a.x);
  dl=(b->b.x-a->b.x)*(b->b.y-b->a.y)-(b->b.y-a->b.y)*(b->b.x-b->a.x);
  dt=(a->a.x-a->b.x)*(b->b.y-a->b.y)-(a->a.y-a->b.y)*(b->b.x-a->b.x);
  if(fabs(dd)<eps)
    return false;
  l=dl/dd;
  t=dt/dd;
  if(t<-eps)
    return false;
  if(t>1+eps)
    return false;
  if(l<-eps)
    return false;
  if(l>1+eps)
    return false;
  p->x=a->a.x*l+(1-l)*a->b.x;
  p->y=a->a.y*l+(1-l)*a->b.y;
  return true;
}

int intersect(ANG *a, ANG *b, ANG *tmp)
{
  bool f1,f2,f3,f4;
  ANG t1,t2;
  POINT p;
  bool flag;
  if(vp(b->b,a->a)>eps)
    return 2;
  if(vp(a->b,b->a)>eps)
    return 2;
  if(fabs(vp(a))<eps)
    return 2;
  if(fabs(vp(b))<eps)
    return 2;
  f1=isin(a,b->a);
  f2=isin(a,b->b);
  f3=isin(b,a->a);
  f4=isin(b,a->b);
  if(f1&&f2&&f3&&f4)
    return 1;
  if(f1&&f2)
  {
    if(f3)
    {
      divide(a,&(b->b),&t1,&t2);
      (*a)=t2;
      return 2;
    }
    if(f4)
    {
      divide(a,&(b->a),&t1,&t2);
      (*a)=t1;
      return 2;
    }
    divide(a,&(b->a),&t1,&t2);
    (*a)=t1;
    divide(&t2,&(b->b),&t1,&t2);
    (*tmp)=t2;
    return 3;
  }
  if(f3&&f4)
  {
    if(f1)
    {
      divide(b,&(a->b),&t1,&t2);
      (*b)=t2;
      return 2;
    }
    if(f2)
    {
      divide(b,&(a->a),&t1,&t2);
      (*b)=t1;
      return 2;
    }
    divide(b,&(a->a),&t1,&t2);
    (*b)=t1;
    divide(&t2,&(a->b),&t1,&t2);
    (*tmp)=t2;
    return 3;
  }
  if(f1&&f3)
  {
    if(divide(a,&(b->b),&t1,&t2))
    {
      b->b=b->a;
      return 2;
    }
    else
    {
      a->b=a->a;
      return 2;
    }
  }
  if(f2&&f4)
  {
    if(divide(a,&(b->a),&t1,&t2))
    {
      b->b=b->a;
      return 2;
    }
    else
    {
      a->b=a->a;
      return 2;
    }
  }
  flag=inter(a,b,&p);
  if(f1&&f4)
  {
    b->a=p;
    a->b=p;
    return 2;
  }
  if(f2&&f3)
  {
    a->a=p;
    b->b=p;
    return 2;
  }
  if(flag)
  {
    if(f1)
    {
      divide(a,&(b->a),&t1,&t2);
      (*a)=t1;
      tmp->b=b->b;
      b->b=p;
      tmp->a=p;
      return 3;
    }
    if(f2)
    {
      divide(a,&(b->b),&t1,&t2);
      (*tmp)=t2;
      a->b=p;
      b->a=p;
      return 3;
    }
    if(f3)
    {
      divide(b,&(a->a),&t1,&t2);
      (*tmp)=t1;
      a->b=p;
      b->a=p;
      return 3;
    }
    if(f4)
    {
      divide(b,&(a->b),&t1,&t2);
      (*tmp)=t2;
      a->a=p;
      b->b=p;
      return 3;
    }
  }
  if(f1)
  {
    divide(a,&(b->a),&t1,&t2);
    (*a)=t1;
    return 2;
  }
  if(f2)
  {
    divide(a,&(b->b),&t1,&t2);
    (*a)=t2;
    return 2;
  }
  if(f3)
  {
    divide(b,&(a->a),&t1,&t2);
    (*b)=t1;
    return 2;
  }
  if(f4)
  {
    divide(b,&(a->b),&t1,&t2);
    (*b)=t2;
    return 2;
  }
  if(flag)
  {
    if(divide(b,&(a->a),&t1,&t2))
    {
      a->a=p;
      b->b=p;
    }
    else
    {
      a->b=p;
      b->a=p;
    }
    return 2;
  }
  else
  {
    if(divide(b,&(a->a),&t1,&t2))
    {
      a->a=a->b;
    }
    else
      b->a=b->b;
    return 2;
  }
  return 2;
}

int main()
{
  int i,j;
  POINT aa,bb;
  ANG tmp;
  int f;
  double ans;
  fi=fopen("input.txt","rt");
  fo=fopen("output.txt","wt");

  fscanf(fi,"%d%d",&n,&m);
  fscanf(fi,"%lf%lf",&st.x,&st.y);
  for(i=0;i<n;i++)
  {
    fscanf(fi,"%lf%lf",&aa.x,&aa.y);
    fscanf(fi,"%lf%lf",&bb.x,&bb.y);
    b[i].a.x=aa.x-st.x;
    b[i].a.y=aa.y-st.y;
    b[i].b.x=bb.x-st.x;
    b[i].b.y=bb.y-st.y;
  }
  k=n;
  aa.x=0;
  aa.y=0;
  bb.x=0;
  bb.y=m;
  b[k].a.x=aa.x-st.x;
  b[k].a.y=aa.y-st.y;
  b[k].b.x=bb.x-st.x;
  b[k].b.y=bb.y-st.y;
  k++;
  aa.x=0;
  aa.y=0;
  bb.x=m;
  bb.y=0;
  b[k].a.x=aa.x-st.x;
  b[k].a.y=aa.y-st.y;
  b[k].b.x=bb.x-st.x;
  b[k].b.y=bb.y-st.y;
  k++;
  aa.x=m;
  aa.y=m;
  bb.x=0;
  bb.y=m;
  b[k].a.x=aa.x-st.x;
  b[k].a.y=aa.y-st.y;
  b[k].b.x=bb.x-st.x;
  b[k].b.y=bb.y-st.y;
  k++;
  aa.x=m;
  aa.y=m;
  bb.x=m;
  bb.y=0;
  b[k].a.x=aa.x-st.x;
  b[k].a.y=aa.y-st.y;
  b[k].b.x=bb.x-st.x;
  b[k].b.y=bb.y-st.y;
  k++;
  n=k;
  for(i=0;i<n;i++)
    make_good(&b[i]);

  for(i=0;i<n;i++)
  {
    for(j=i+1;j<n;j++)
    {
      f=intersect(&b[i],&b[j],&tmp);
      if(f>=3)
        b[n++]=tmp;
    }
  }
  ans=0.0;
  for(i=0;i<n;i++)
    ans+=s(&b[i]);

  fprintf(fo,"%0.5lf\n",ans);

  fclose(fi);
  fclose(fo);
  return 0;
}
