#define ONLINE
#include <stdio.h>
#include <string.h>

struct TEdge {
  long from,to;
  short mark;
  TEdge*next;
};
class TGraph {
  private:
    long n_verts,n_edges_bound,n_edges,p_target;
    long n_comps,n_compedges,p_target_comp;
    TEdge*edges_cont,*compedges_cont,**edges,**compedges;
    long*colors,*seq,*branches;
    long c_colors,c_seq,c_branches;
    long*queue; TEdge**stack; char*mark;
    long stack_point,queue_len,queue_pos,c_common;
    long*fromp; TEdge**byedge;
    int f_seq,f_paint;
    void clearedgemarks(TEdge*,const long);
    void search_depth(long);
    void search_depth_branch(long);
    void search_breadth_cond(long);
    void markway(long);
  public:
    TGraph(void);
    ~TGraph();
    void Create(void);
    void Delete(void);
    void scan(void);
    void condense(void);
    long countcommonbridges(long,long);
};

TGraph graph;

int main(void) {
  #ifdef ONLINE
  freopen("magic.in","rt",stdin);
  freopen("magic.out","wt",stdout);
  #endif
  long n_quests,i_quest;
  graph.scan();
  graph.condense();
  scanf("%ld",&n_quests);
  for (i_quest=0; i_quest<n_quests; i_quest++) {
    long v,w;
    scanf("%ld%ld",&v,&w); v--; w--;
    printf("%ld\n",graph.countcommonbridges(v,w));
  }
  #ifdef ONLINE
  fclose(stdin);
  fclose(stdout);
  #endif
  return(0);
}


void TGraph::search_breadth_cond(long start) {
  long cur,next; TEdge*edge;
  *queue=start; queue_len=1; mark[start]=1;
  if (start==p_target_comp) return;
  for (queue_pos=0; queue_pos<queue_len; queue_pos++) {
    cur=queue[queue_pos];
    for (edge=compedges[cur]; edge; edge=edge->next) {
      next=edge->to;
      if (mark[next]) continue;
      queue[queue_len++]=next; mark[next]=1;
      fromp[next]=cur; byedge[next]=edge;
      if (next==p_target_comp) return;
    }
  }
}
void TGraph::markway(long start) {
  memset(mark,0,sizeof(char)*n_comps);
  memset(fromp,-1,sizeof(long)*n_comps);
  memset(byedge,0,sizeof(TEdge*)*n_comps);
  search_breadth_cond(start);
  long vert;
  for (vert=p_target_comp; fromp[vert]>=0; vert=fromp[vert]) {
    if (byedge[vert]->mark) c_common++;
    byedge[vert]->mark++;
  }
}
long TGraph::countcommonbridges(long p_0,long p_1) {
  p_0=colors[p_0]; p_1=colors[p_1];
  if ((branches[p_0]<0)||(branches[p_1]<0)) return(0);
  if (branches[p_0]!=branches[p_1]) return(0);
  c_common=0;
  markway(p_0); markway(p_1);
  clearedgemarks(compedges_cont,n_compedges);
  return(c_common);
}

void TGraph::search_depth(long start) {
  long cur,next; TEdge*edge;
  if (f_seq) { *seq=start; c_seq=1; }
  *queue=start; *stack=edges[start]; stack_point=0;
  mark[start]=1; if (f_paint) colors[start]=c_colors;
  while (stack_point>=0) {
    if (!stack[stack_point]) { stack_point--; continue; }
    cur=queue[stack_point]; edge=stack[stack_point];
    stack[stack_point]=stack[stack_point]->next;
    if (f_paint) if (edge->mark) continue;
    next=edge->to;
    if (mark[next]) continue;
    if (f_seq) { seq[c_seq++]=next; edge->mark++; }
    stack_point++;
    queue[stack_point]=next; stack[stack_point]=edges[next];
    mark[next]=1; if (f_paint) colors[next]=c_colors;
  }
}
void TGraph::search_depth_branch(long start) {
  long cur,next; TEdge*edge;
  *queue=start; *stack=compedges[start]; stack_point=0;
  mark[start]=1; branches[start]=c_branches;
  while (stack_point>=0) {
    if (!stack[stack_point]) { stack_point--; continue; }
    cur=queue[stack_point]; edge=stack[stack_point];
    stack[stack_point]=stack[stack_point]->next;
    next=edge->to;
    if (mark[next]) continue;
    if (next==p_target_comp) continue;
    stack_point++;
    queue[stack_point]=next; stack[stack_point]=compedges[next];
    mark[next]=1; branches[next]=c_branches;
  }
}
void TGraph::condense(void) {
  long i; TEdge*edge;
  f_seq++;
  memset(mark,0,sizeof(char)*n_verts);
  search_depth(p_target);
  f_seq--;
  f_paint++;
  memset(colors,-1,sizeof(long)*n_verts); c_colors=0;
  memset(mark,0,sizeof(char)*n_verts);
  for (i=0; i<c_seq; i++) if (colors[seq[i]]<0) {
    search_depth(seq[i]);
    c_colors++;
  }
  f_paint--;
  clearedgemarks(edges_cont,n_edges);
  n_comps=c_colors;
  p_target_comp=colors[p_target];
  memset(compedges,0,sizeof(TEdge*)*n_verts); n_compedges=0;
  for (i=0; i<n_edges; i++) if (colors[edges_cont[i].from]!=colors[edges_cont[i].to]) {
    long v,w;
    v=colors[edges_cont[i].from]; w=colors[edges_cont[i].to];
    compedges_cont[n_compedges].from=v; compedges_cont[n_compedges].to=w;
    compedges_cont[n_compedges].next=compedges[v];
    compedges[v]=&compedges_cont[n_compedges++];
  }
  clearedgemarks(compedges_cont,n_compedges);
  memset(branches,-1,sizeof(long)*n_comps); c_branches=0;
  memset(mark,0,sizeof(char)*n_comps);
  for (edge=compedges[p_target_comp]; edge; edge=edge->next) if (branches[edge->to]<0) {
    search_depth_branch(edge->to);
    c_branches++;
  }
}
    

void TGraph::scan(void) {
  Delete();
  scanf("%ld%ld",&n_verts,&n_edges_bound);
  n_edges_bound<<=1;
  Create();
  long i_edges;
  scanf("%ld",&p_target); p_target--;
  memset(edges,0,sizeof(TEdge*)*n_verts); n_edges=0;
  for (i_edges=0; i_edges<n_edges_bound; i_edges+=2) {
    long v,w;
    scanf("%ld%ld",&v,&w); v--; w--;
    edges_cont[n_edges].from=v; edges_cont[n_edges].to=w;
    edges_cont[n_edges].next=edges[v];
    edges[v]=&edges_cont[n_edges++];
    edges_cont[n_edges].from=w; edges_cont[n_edges].to=v;
    edges_cont[n_edges].next=edges[w];
    edges[w]=&edges_cont[n_edges++];
  }
  clearedgemarks(edges_cont,n_edges);
}
void TGraph::clearedgemarks(TEdge*cont,const long n) {
  long i_edge;
  for (i_edge=0; i_edge<n; i_edge++) cont[i_edge].mark=0;
}
    

TGraph::TGraph(void) {
  edges_cont=0; compedges_cont=0; edges=0; compedges=0;
  colors=0; seq=0; branches=0;
  queue=0; stack=0; mark=0;
  fromp=0; byedge=0;
  f_seq=0; f_paint=0;
}
TGraph::~TGraph() {
  Delete();
}
void TGraph::Create(void) {
  edges_cont=new TEdge[n_edges_bound]; compedges_cont=new TEdge[n_edges_bound];
  edges=new TEdge*[n_verts]; compedges=new TEdge*[n_verts];
  colors=new long[n_verts]; seq=new long[n_verts]; branches=new long[n_verts];
  queue=new long[n_verts]; stack=new TEdge*[n_verts]; mark=new char[n_verts];
  fromp=new long[n_verts]; byedge=new TEdge*[n_verts];
}
void TGraph::Delete(void) {
  if (edges_cont) delete[]edges_cont; if (compedges_cont) delete[]compedges_cont;
  if (edges) delete[]edges; if (compedges) delete[]compedges;
  if (colors) delete[]colors; if (seq) delete[]seq; if (branches) delete[]branches;
  if (queue) delete[]queue; if (stack) delete[]stack; if (mark) delete[]mark;
  if (fromp) delete[]fromp; if (byedge) delete[]byedge;
}


