#define ONLINE
//#define DEBUG
#include <stdio.h>
#include <string.h>
#include <math.h>

#define EPS ((long double)1e-5)

struct TPoint {
  long double a,b;
  long double x,y,z;
  void scan(void);
  void convert(void);
  long double dist(void);
  TPoint operator-(const TPoint) const;
};

class TSphere {
  private:
    short n_points;
    TPoint*points;
    long double radius,maxdist;
  public:
    TSphere(void);
    ~TSphere();
    void Create(void);
    void Delete(void);
    void scan(const short);
    int reachable(const short,const short);
};

class TGraph {
  private:
    short n_verts,p_start,p_target;
    char*matrix_cont,**matrix;
    short*pathlen;
    short*queue; char*mark;
    short queue_len,queue_pos;
    TSphere sphere;
  protected:
    void CreateTable(char*&,char**&,const short);
  public:
    TGraph(void);
    ~TGraph();
    void Create(void);
    void Delete(void);
    void scan(void);
    void print_pathlen(void);
    void search(void);
};

TGraph graph;

int main(void) {
  #ifdef ONLINE
  freopen("sphere.in","rt",stdin);
  freopen("sphere.out","wt",stdout);
  #endif
  graph.scan();
  graph.search();
  graph.print_pathlen();
  #ifdef ONLINE
  fclose(stdin);
  fclose(stdout);
  #endif
  return(0);
}


void TGraph::search(void) {
  short cur,next;
  memset(pathlen,-1,sizeof(short)*n_verts);
  memset(mark,0,sizeof(char)*n_verts);
  *queue=p_start; queue_len=1; mark[p_start]=1; pathlen[p_start]=0;
  for (queue_pos=0; queue_pos<queue_len; queue_pos++) {
    cur=queue[queue_pos];
    for (next=0; next<n_verts; next++) if (matrix[cur][next]) {
      if (mark[next]) continue;
      queue[queue_len++]=next;
      mark[next]=1; pathlen[next]=pathlen[cur]+1;
    }
  }
}


void TGraph::scan(void) {
  Delete();
  scanf("%hd",&n_verts);
  Create();
  short i,j;
  scanf("%hd%hd",&p_start,&p_target); p_start--; p_target--;
  sphere.scan(n_verts);
  for (i=0; i<n_verts; i++) matrix[i][i]=1;
  for (i=0; i<n_verts; i++) for (j=i+1; j<n_verts; j++)
  matrix[j][i]=matrix[i][j]=sphere.reachable(i,j);
}
void TGraph::print_pathlen(void) {
  printf("%hd\n",pathlen[p_target]);
}


void TSphere::scan(const short n) {
  Delete();
  n_points=n;
  Create();
  short i;
  scanf("%Lf%Lf",&radius,&maxdist);
  for (i=0; i<n_points; i++) points[i].scan();
  for (i=0; i<n_points; i++) points[i].convert();
}
int TSphere::reachable(const short v,const short w) {
  long double dist;
  TPoint p=points[v]-points[w];
  dist=asin(p.dist()/2)*2;
  #ifdef DEBUG
  printf("dist(%hd,%hd)=%Lf %Lf\n",v,w,dist*radius,maxdist);
  #endif
  return(dist*radius-maxdist<EPS);
}


void TPoint::scan(void) {
  char str_a[2],str_b[2];
  scanf("%Lf%s%Lf%s",&a,str_a,&b,str_b);
  if ((*str_a=='S')||(*str_a=='s')) a=-a;
  if ((*str_b=='W')||(*str_b=='w')) b=-b;
}
void TPoint::convert(void) {
  long double A,B;
  A=a*M_PI/180; B=b*M_PI/180;
  x=cos(A)*cos(B);
  y=cos(A)*sin(B);
  z=sin(A);
}
long double TPoint::dist(void) {
  long double d;
  d=sqrt(x*x+y*y+z*z);
  return(d);
}
TPoint TPoint::operator-(const TPoint arg) const {
  TPoint res;
  res.x=x-arg.x; res.y=y-arg.y; res.z=z-arg.z;
  return(res);
}


TSphere::TSphere(void) {
  points=0;
}
TSphere::~TSphere() {
  Delete();
}
void TSphere::Create(void) {
  points=new TPoint[n_points];
}
void TSphere::Delete(void) {
  if (points) delete[]points;
}

TGraph::TGraph(void) {
  matrix_cont=0; matrix=0;
  pathlen=0;
  queue=0; mark=0;
}
TGraph::~TGraph() {
  Delete();
}
void TGraph::CreateTable(char*&cont,char**&table,const short n) {
  long n_lines,n_cells;
  n_lines=(long)n; n_cells=n_lines*n_lines;
  long i,j;
  cont=new char[n_cells]; table=new char*[n_lines];
  for (i=0,j=0; i<n_lines; i++,j+=n_lines) table[i]=&cont[j];
}
void TGraph::Create(void) {
  CreateTable(matrix_cont,matrix,n_verts);
  pathlen=new short[n_verts];
  queue=new short[n_verts]; mark=new char[n_verts];
}
void TGraph::Delete(void) {
  if (matrix_cont) delete[]matrix_cont; if (matrix) delete[]matrix;
  if (pathlen) delete[]pathlen;
  if (queue) delete[]queue; if (mark) delete[]mark;
}


