#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#define eps_s 1e-7
#define eps_b 1e-8

struct POINT {
  double x,y;
};

struct POLIGON {
  POINT a,b,c,d;
};

FILE *fi, *fo;
POLIGON m1,m2,m3;
double s1,s2,s3;
POINT v2,v3;
double sina3, cosa3;
double lx,ly;
POINT f;
double ang;

double s(POINT a, POINT b, POINT c)
{
  b.x-=a.x;
  b.y-=a.y;
  c.x-=a.x;
  c.y-=a.y;
  return fabs(b.x*c.y-c.x*b.y)/2.0;
}

double s(POLIGON x)
{
  double ans;
  ans=0;
  ans+=(x.a.x-x.b.x)*(x.a.y+x.b.y)/2.0;
  ans+=(x.b.x-x.c.x)*(x.b.y+x.c.y)/2.0;
  ans+=(x.c.x-x.d.x)*(x.c.y+x.d.y)/2.0;
  ans+=(x.d.x-x.a.x)*(x.d.y+x.a.y)/2.0;
  return fabs(ans);
}

bool isin(POLIGON x, POINT p)
{
  double s1,s2;
  s1=s(x);
  s2=0;
  s2+=s(x.a,x.b,p);
  s2+=s(x.c,x.b,p);
  s2+=s(x.a,x.d,p);
  s2+=s(x.c,x.d,p);
  if(fabs(s2-s1)<eps_s)
    return true;
  else
    return false;
}

bool isin(POLIGON x, POLIGON y)
{
  if(!isin(x,y.a)) return false;
  if(!isin(x,y.b)) return false;
  if(!isin(x,y.c)) return false;
  if(!isin(x,y.d)) return false;
  return true;
}

void findpoint(double k, double sina, double cosa, POINT v, POINT *p)
{
  double dd,dx,dy;
  dd=(1-k*cosa)*(1-k*cosa)+k*k*sina*sina;
  dx=v.x*(1-k*cosa)-v.y*k*sina;
  dy=(1-k*cosa)*v.y+k*sina*v.x;
  p->x=dx/dd;
  p->y=dy/dd;
}

void findv(double k, double alfa, POINT p, POINT *v)
{
  double sina, cosa;
  sina=sin(alfa);
  cosa=cos(alfa);
  v->x=(1-k*cosa)*p.x+k*sina*p.y;
  v->y=(1-k*cosa)*p.y-k*sina*p.x;
}

void readpoint(POINT *p)
{
  fscanf(fi,"%lf%lf",&p->x,&p->y);
}

void wr_point(POINT p)
{
  fprintf(fo,"%0.7lf %0.7lf\n",p.x,p.y);
}

void wr_poligon(POLIGON a)
{
  wr_point(a.a);
  wr_point(a.b);
  wr_point(a.c);
  wr_point(a.d);
}

void build_poligon(POLIGON *ans, double alfa)
{
  POINT v;
  double cosa,sina;
  double k;
  k=s2/s1;
  findv(k,alfa,f,&v);
  cosa=cos(alfa);
  sina=sin(alfa);
  ans->a=v;
  ans->b.x=v.x+lx*cosa*k;
  ans->b.y=v.y+lx*sina*k;
  ans->d.x=v.x-ly*sina*k;
  ans->d.y=v.y+ly*cosa*k;
  ans->c.x=ans->b.x+ans->d.x-v.x;
  ans->c.y=ans->b.y+ans->d.y-v.y;
}

double solv()
{
  double b,e,c;
  POLIGON m;
  b=0;
  e=ang;
  build_poligon(&m,b);
  if(isin(m1,m)&&isin(m,m3))
    return b;
  build_poligon(&m,e);
  if(isin(m1,m)&&isin(m,m3))
    return e;
  while((e-b)>eps_b)
  {
    c=(b+e)/2.0;
    build_poligon(&m,c);
    if(!isin(m1,m))
      e=c;
    else
      if(!isin(m,m3))
        b=c;
      else
        return c;
  }
  return (b+e)/2.0;
}

double solv1()
{
  double b,e,c;
  POLIGON m;
  b=0;
  e=M_PI;
  while((e-b)>eps_b)
  {
    c=(b+e)/2.0;
    build_poligon(&m,c);
    if(!isin(m1,m))
      e=c;
    else
      if(!isin(m,m3))
        b=c;
      else
        return c;
  }
  return (b+e)/2.0;
}

double solv2()
{
  double b,e,c;
  POLIGON m;
  b=0;
  e=-M_PI;
  while((e-b)>eps_b)
  {
    c=(b+e)/2.0;
    build_poligon(&m,c);
    if(!isin(m1,m))
      e=c;
    else
      if(!isin(m,m3))
        b=c;
      else
        return c;
  }
  return (b+e)/2.0;
}

int main()
{
  double alfa,betta;
  fi=fopen("maps.in","rt");
  fo=fopen("maps.out","wt");

  fscanf(fi,"%lf%lf%lf",&s1,&lx,&ly);
  fscanf(fi,"%lf",&s2);
  fscanf(fi,"%lf",&s3);
  readpoint(&m3.a);
  readpoint(&m3.b);
  readpoint(&m3.c);
  readpoint(&m3.d);
  m1.a.x=0;
  m1.a.y=0;
  m1.b.x=lx;
  m1.b.y=0;
  m1.c.x=lx;
  m1.c.y=ly;
  m1.d.x=0;
  m1.d.y=ly;
  sina3=(m3.b.y-m3.a.y)/(lx*s3/s1);
  cosa3=(m3.b.x-m3.a.x)/(lx*s3/s1);

  ang=atan2(sina3, cosa3);

  findpoint(s3/s1,sina3,cosa3,m3.a,&f);
/*  if(ang>0)
    alfa=solv1();
  else
    betta=solv2();*/
  alfa=solv();

  build_poligon(&m2,alfa);
  if(isin(m1,m2)&&isin(m2,m3))
  {
    wr_poligon(m2);
  }
  else
  {
/*    build_poligon(&m2,betta);
    if(isin(m1,m2)&&isin(m2,m3))
      wr_poligon(m2);
    else*/
    fprintf(fo,"impossible\n");
  }

  fclose(fi);
  fclose(fo);
  return 0;
}
